@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: backgammon.h,v 1.272 2004/01/03 13:35:08 uid65656 Exp $
+ * $Id: backgammon.h,v 1.280 2004/03/18 23:29:14 oysteijo Exp $
  */
 
 #ifndef _BACKGAMMON_H_
@@ -88,6 +88,7 @@ typedef RETSIGTYPE (*psighandler)( int );
 typedef enum _gnubgwindow {
   WINDOW_MAIN = 0,
   WINDOW_GAME,
+  WINDOW_ANALYSIS,
   WINDOW_ANNOTATION,
   WINDOW_HINT,
   WINDOW_MESSAGE,
@@ -95,19 +96,23 @@ typedef enum _gnubgwindow {
 } gnubgwindow;
 
 typedef struct _windowgeometry {
-#if USE_GTK
-  gint nWidth, nHeight;
-  gint nPosX, nPosY;
-#else
   int nWidth, nHeight;
   int nPosX, nPosY;
-#endif
 } windowgeometry;
 
-/* predefined board designs */
-
-extern windowgeometry awg[ NUM_WINDOWS ];
+typedef struct _windowobject {
+	char* winName;
+	int showing;
+	int docked;
+	int dockable;
+	int undockable;
+#if USE_GTK
+	GtkWidget* pwWin;
+#endif
+	windowgeometry wg;
+} windowobject;
 
+extern windowobject woPanel[NUM_WINDOWS];
 
 typedef struct _monitor {
 #if USE_GTK
@@ -137,9 +142,11 @@ typedef enum _playertype {
     PLAYER_EXTERNAL, PLAYER_HUMAN, PLAYER_GNU, PLAYER_PUBEVAL
 } playertype;
 
+#define MAX_NAME_LEN 32
+
 typedef struct _player {
   /* For all player types: */
-  char szName[ 32 ];
+  char szName[ MAX_NAME_LEN ];
 
   playertype pt;
 
@@ -495,10 +502,11 @@ extern int fNextTurn, fComputing;
 
 /* User settings. */
 extern int fAutoGame, fAutoMove, fAutoRoll, fAutoCrawford, cAutoDoubles,
-    fCubeUse, fDisplay, fAutoBearoff, fShowProgress,
+    fCubeUse, fDisplay, fDockPanels, fAutoBearoff, fShowProgress,
     nBeavers, fJacoby,
-    fOutputRawboard, fAnnotation, cAnalysisMoves, fAnalyseCube,
-    fAnalyseDice, fAnalyseMove, fRecord, fMessage, fAnalysis, fGameList, nDefaultLength;
+    fOutputRawboard, cAnalysisMoves, fAnalyseCube,
+    fAnalyseDice, fAnalyseMove, fRecord,
+	nDefaultLength, nToolbarStyle;
 extern int fInvertMET;
 extern int fConfirm, fConfirmSave;
 extern float rAlpha, rAnneal, rThreshold, arLuckLevel[ LUCK_VERYGOOD + 1 ],
@@ -873,6 +881,7 @@ extern void CommandAccept( char * ),
     CommandLoadGame( char * ),
     CommandLoadMatch( char * ),
     CommandLoadPosition( char * ),
+    CommandLoadPython( char * ),
     CommandMove( char * ),
     CommandMWC2Eq( char * ),
     CommandNewGame( char * ),
@@ -920,6 +929,7 @@ extern void CommandAccept( char * ),
     CommandSetAnalysisThresholdVeryGood( char * ),
     CommandSetAnalysisThresholdVeryLucky( char * ),
     CommandSetAnalysisThresholdVeryUnlucky( char * ),
+    CommandSetAnalysisWindows ( char * ),
     CommandSetAnnotation( char * ),
     CommandSetAppearance( char * ),
     CommandSetAutoAnalysis( char * ),
@@ -959,6 +969,7 @@ extern void CommandAccept( char * ),
     CommandSetDice( char * ),
     CommandSetDisplay( char * ),
     CommandSetDisplayPanels( char *),
+    CommandSetDockPanels( char *),
     CommandSetEvalCandidates( char * ),
     CommandSetEvalCubeful( char * ),
     CommandSetEvalDeterministic( char * ),
@@ -1015,7 +1026,8 @@ extern void CommandAccept( char * ),
     CommandSetExportParametersRollout ( char * ),
     CommandSetExportPNGSize ( char *),
     CommandSetExportHtmlSize ( char *),
-    CommandSetGeometryAnnotation ( char * ),
+    CommandSetGameList ( char * ),
+    CommandSetGeometryAnalysis( char * ),
     CommandSetGeometryGame ( char * ),
     CommandSetGeometryHint ( char * ),
     CommandSetGeometryMain ( char * ),
@@ -1198,6 +1210,7 @@ extern void CommandAccept( char * ),
     CommandSetTCUnname( char * ),
     CommandSetTimeControl( char * ),
 #endif
+    CommandSetToolbar( char * ),
     CommandSetTrainingAlpha( char * ),
     CommandSetTrainingAnneal( char * ),
     CommandSetTrainingThreshold( char * ),
@@ -1219,6 +1232,7 @@ extern void CommandAccept( char * ),
     CommandShowAutomatic( char * ),
     CommandShowBoard( char * ),
     CommandShowBeavers( char * ),
+    CommandShowBuildInfo( char * ),
     CommandShowCache( char * ),
     CommandShowCalibration( char * ),
     CommandShowCheat( char * ),
@@ -1227,6 +1241,7 @@ extern void CommandAccept( char * ),
     CommandShowConfirm( char * ),
     CommandShowCopying( char * ),
     CommandShowCrawford( char * ),
+    CommandShowCredits( char * ),
     CommandShowCube( char * ),
     CommandShowCubeEfficiency( char * ),
     CommandShowDelay( char * ),
