@@ -18,9 +18,10 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* $Id: misc3d.c,v 1.21 2004/01/21 09:46:20 uid68519 Exp $
+* $Id: misc3d.c,v 1.28 2004/03/23 10:20:41 Superfly_Jon Exp $
 */
 
+#include "config.h"
 #include <math.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -261,7 +262,9 @@ void FindNamedTexture(TextureInfo** textureInfo, char* name)
 		}
 	}
 	*textureInfo = 0;
-	g_print("Texture %s not in texture info file\n", name);
+	/* Only warn user if textures.txt file has been loaded */
+	if (ListSize(&textures) > 0)
+		g_print("Texture %s not in texture info file\n", name);
 }
 
 void FindTexture(TextureInfo** textureInfo, char* file)
@@ -277,23 +280,29 @@ void FindTexture(TextureInfo** textureInfo, char* file)
 		}
 	}
 	*textureInfo = 0;
-	g_print("Texture %s not in texture info file\n", file);
+	/* Only warn user if textures.txt file has been loaded */
+	if (ListSize(&textures) > 0)
+		g_print("Texture %s not in texture info file\n", file);
 }
 
 #define TEXTURE_FILE "textures.txt"
 #define TEXTURE_FILE_VERSION 2
 
-void LoadTextureInfo()
-{
+void LoadTextureInfo(int FirstPass)
+{	/* May be called several times, no errors shown on first pass */
 	FILE* fp;
 	char *szFile;
 	#define BUF_SIZE 100
 	char buf[BUF_SIZE];
 
+	if (!FirstPass && ListSize(&textures) > 0)
+		return;	/* Ignore multiple calls after a successful load */
+
 	ListInit(&textures, sizeof(TextureInfo));
 
 	if ( ! ( szFile = PathSearch( TEXTURE_FILE, szDataDirectory ) ) ) {
-		g_print( "PathSearch failed!\n" );
+		if (!FirstPass)
+			g_print( "PathSearch failed!\n" );
 		return;
 	}
 
@@ -301,13 +310,15 @@ void LoadTextureInfo()
 	free(szFile);
 	if (!fp)
 	{
-		g_print("Error: Texture file (%s) not found\n", TEXTURE_FILE);
+		if (!FirstPass)
+			g_print("Error: Texture file (%s) not found\n", TEXTURE_FILE);
 		return;
 	}
 
 	if (!fgets(buf, BUF_SIZE, fp) || atoi(buf) != TEXTURE_FILE_VERSION)
 	{
-		g_print("Error: Texture file (%s) out of date\n", TEXTURE_FILE);
+		if (!FirstPass)
+			g_print("Error: Texture file (%s) out of date\n", TEXTURE_FILE);
 		return;
 	}
 
@@ -320,7 +331,7 @@ void LoadTextureInfo()
 
 		/* filename */
 		if (!fgets(buf, BUF_SIZE, fp))
-			return;	/* finished */
+			break;	/* finished */
 		len = strlen(buf);
 		if (len > 0 && buf[len - 1] == '\n')
 		{
@@ -534,6 +545,9 @@ void Set3dSettings(BoardData* bd, const renderdata *prd)
 	bd->bgInTrays = prd->bgInTrays;
 	bd->shadowDarkness = prd->shadowDarkness;
 	SetShadowDimness3d(bd);
+	if (prd->curveAccuracy != bd->curveAccuracy && bd->boardPoints)
+		/* Clear data as accuracy is changing */
+		freeEigthPoints(&bd->boardPoints, bd->curveAccuracy);
 	bd->curveAccuracy = prd->curveAccuracy;
 	bd->testSkewFactor = prd->testSkewFactor;
 	bd->boardAngle = prd->boardAngle;
@@ -1456,10 +1470,11 @@ void calculateEigthPoints(float ****boardPoints, float radius, int accuracy)
 	}
 }
 
-void freeEigthPoints(float ***boardPoints, int accuracy)
+void freeEigthPoints(float ****boardPoints, int accuracy)
 {
 	int corner_steps = (accuracy / 4) + 1;
-	Free3d(boardPoints, corner_steps, corner_steps);
+	Free3d(*boardPoints, corner_steps, corner_steps);
+	*boardPoints = 0;
 }
 
 void SetColour(float r, float g, float b, float a)
@@ -1559,10 +1574,10 @@ void RationalizeBox(ClipBox* pCb)
 	midY = (int)BoxMidHeight(pCb);
 	maxXoff = (int)MAX(midX - pCb->x, pCb->xx - midX) + 1;
 	maxYoff = (int)MAX(midY - pCb->y, pCb->yy - midY) + 1;
-	pCb->x = midX - maxXoff;
-	pCb->xx = midX + maxXoff;
-	pCb->y = midY - maxYoff;
-	pCb->yy = midY + maxYoff;
+	pCb->x = (float)(midX - maxXoff);
+	pCb->xx = (float)(midX + maxXoff);
+	pCb->y = (float)(midY - maxYoff);
+	pCb->yy = (float)(midY + maxYoff);
 }
 
 void RestrictiveRedraw()
@@ -1665,8 +1680,13 @@ void RestrictiveRender(BoardData *bd)
 			numRestrictFrames--;
 		else
 		{
-			freezeRestrict = 0;
-			break;
+			if (numRestrictFrames > 1)
+				numRestrictFrames--;
+			else
+			{
+				freezeRestrict = 0;
+				break;
+			}
 		}
 	}
 }
@@ -1678,7 +1698,7 @@ int MouseMove3d(BoardData *bd, int x, int y)
 		getProjectedPieceDragPos(x, y, bd->dragPos);
 		updateMovingPieceOccPos(bd);
 
-		if(bd->quickDraw)
+		if(bd->quickDraw && numRestrictFrames != -1)
 		{
 			if (!freezeRestrict)
 				CopyBox(&eraseCb, &lastCb);
@@ -1695,20 +1715,26 @@ int MouseMove3d(BoardData *bd, int x, int y)
 		return 0;
 }
 
-void RestrictiveStartMouseMove(BoardData *bd, int pos, int depth)
+void RestrictiveStartMouseMove(int pos, int depth)
 {
 	float erasePos[3];
-	getPiecePos(pos, depth, fClockwise, erasePos);
-	RestrictiveDrawFrame(erasePos, PIECE_HOLE, PIECE_HOLE, PIECE_DEPTH);
-	CopyBox(&eraseCb, &cb[numRestrictFrames]);
+	if (numRestrictFrames != -1)
+	{
+		getPiecePos(pos, depth, fClockwise, erasePos);
+		RestrictiveDrawFrame(erasePos, PIECE_HOLE, PIECE_HOLE, PIECE_DEPTH);
+		CopyBox(&eraseCb, &cb[numRestrictFrames]);
+	}
 	freezeRestrict = 1;
 }
 
-void RestrictiveEndMouseMove(BoardData *bd, int pos, int depth)
+void RestrictiveEndMouseMove(int pos, int depth)
 {
 	float newPos[3];
 	getPiecePos(pos, depth, fClockwise, newPos);
 
+	if (numRestrictFrames == -1)
+		return;
+
 	if (pos == 26 || pos == 27)
 	{
 		newPos[2] -= PIECE_HOLE / 2.0f;
@@ -1723,9 +1749,6 @@ void RestrictiveEndMouseMove(BoardData *bd, int pos, int depth)
 		EnlargeCurrentToBox(&lastCb);
 
 	freezeRestrict = 0;
-
-	if (numRestrictFrames > 1)
-		numRestrictFrames = -1;
 }
 
 void updateDicePos(Path* path, DiceRotation *diceRot, float dist, float pos[3])
@@ -1807,7 +1830,7 @@ int idleAnimate(BoardData* bd)
 				bd->points[moveDest] = 0;
 
 				if (bd->quickDraw)
-					RestrictiveDrawPiece(bd, bar, abs(bd->points[bar]));
+					RestrictiveDrawPiece(bar, abs(bd->points[bar]));
 			}
 
 			bd->points[moveDest] += bd->turn;
@@ -1818,7 +1841,7 @@ int idleAnimate(BoardData* bd)
 
 			PlaceMovingPieceRotation(bd, moveDest, moveStart);
 
-			if (bd->quickDraw)
+			if (bd->quickDraw && numRestrictFrames != -1)
 			{
 				float new_pos[3];
 				getPiecePos(moveDest, abs(bd->points[moveDest]), fClockwise, new_pos);
@@ -1849,9 +1872,10 @@ int idleAnimate(BoardData* bd)
 		else
 		{
 			updateMovingPieceOccPos(bd);
-			RestrictiveDraw(&temp, bd->movingPos, PIECE_HOLE, PIECE_HOLE, PIECE_DEPTH);
+			if (bd->quickDraw && numRestrictFrames != -1)
+				RestrictiveDraw(&temp, bd->movingPos, PIECE_HOLE, PIECE_HOLE, PIECE_DEPTH);
 		}
-		if (bd->quickDraw)
+		if (bd->quickDraw && numRestrictFrames != -1)
 		{
 			RestrictiveDrawFrame(old_pos, PIECE_HOLE, PIECE_HOLE, PIECE_DEPTH);
 			EnlargeCurrentToBox(&temp);
@@ -1872,7 +1896,7 @@ int idleAnimate(BoardData* bd)
 		}
 		updateDiceOccPos(bd);
 
-		if (bd->quickDraw)
+		if (bd->quickDraw && numRestrictFrames != -1)
 		{
 			float pos[3];
 			float overSize;
@@ -1952,6 +1976,7 @@ int idleWaveFlag(BoardData* bd)
 	float elapsedTime = (float)(get_time() - animStartTime);
 	bd->flagWaved = elapsedTime / 200;
 	updateFlagOccPos(bd);
+	RestrictiveDrawFlag(bd);
 	return 1;
 }
 
@@ -1971,7 +1996,7 @@ void ShowFlag3d(BoardData *bd)
 	waveFlag(bd, 0);
 	updateFlagOccPos(bd);
 
-	RestrictiveRedraw();
+	RestrictiveDrawFlag(bd);
 }
 
 int idleCloseBoard(BoardData* bd)
