@@ -16,24 +16,46 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dice.h,v 1.9 2001/02/23 18:11:22 gtw Exp $
+ * $Id: dice.h,v 1.14 2003/03/28 17:29:35 thyssen Exp $
  */
 
 #ifndef _DICE_H_
 #define _DICE_H_
 
 typedef enum _rng {
-    RNG_ANSI, RNG_BSD, RNG_ISAAC, RNG_MANUAL, RNG_MD5, RNG_MERSENNE, RNG_USER
+    RNG_ANSI, RNG_BBS, RNG_BSD, RNG_ISAAC, RNG_MANUAL, RNG_MD5, RNG_MERSENNE, 
+    RNG_RANDOM_DOT_ORG, RNG_USER, RNG_FILE,
+    NUM_RNGS
 } rng;
 
+extern char *aszRNG[ NUM_RNGS ];
+
+extern char szDiceFilename[];
+
 extern rng rngCurrent;
 
-extern int InitRNG( int *pnSeed, int fSet );
-extern void PrintRNGSeed( void );
-extern void InitRNGSeed( int n );
-extern int RollDice( int anDice[ 2 ] );
+extern int InitRNG( int *pnSeed, int fSet, const rng rngx );
+extern void PrintRNGSeed( const rng rngx );
+extern void InitRNGSeed( int n, const rng rngx );
 
-extern void UserRNGClose();
-extern int UserRNGOpen();
+extern int 
+RollDice( int anDice[ 2 ], const rng rngx );
+
+#if HAVE_LIBGMP
+extern int InitRNGSeedLong( char *sz, rng rng );
+extern int InitRNGBBSModulus( char *sz );
+extern int InitRNGBBSFactors( char *sz0, char *sz1 );
+#endif
+
+#if HAVE_LIBDL
+extern int UserRNGOpen( char * );
+extern void UserRNGClose( void );
+#endif
+
+extern int
+OpenDiceFile( const char *sz );
+
+extern void
+CloseDiceFile( void );
 
 #endif
