@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: external.c,v 1.35 2004/01/01 22:03:45 uid65655 Exp $
+ * $Id: external.c,v 1.39 2004/03/18 23:29:14 oysteijo Exp $
  */
 
 #include "config.h"
@@ -49,7 +49,8 @@
 #include <stdio.h>
 
 #else /* #ifndef WIN32 */
-#include <winsock.h>
+#include <winsock2.h>
+#include <ws2tcpip.h>
 
 #define EWOULDBLOCK             WSAEWOULDBLOCK
 #define EINPROGRESS             WSAEINPROGRESS
@@ -362,10 +363,9 @@ ExtParse( const char *szCommand ) {
 static char *
 ExtEvaluation( extcmd *pec ) {
 
-  char szName[ 32 ], szOpp[ 32 ];
-  int anBoard[ 2 ][ 25 ], anBoardOrig[ 2 ][ 25 ], nMatchTo, anScore[ 2 ],
-    anDice[ 2 ], nCube, fCubeOwner, fDoubled, fTurn, fCrawford,
-    anMove[ 8 ];
+  char szName[ MAX_NAME_LEN ], szOpp[ MAX_NAME_LEN ];
+  int anBoard[ 2 ][ 25 ], nMatchTo, anScore[ 2 ],
+    anDice[ 2 ], nCube, fCubeOwner, fDoubled, fTurn, fCrawford;
   float arOutput[ NUM_ROLLOUT_OUTPUTS ];
   cubeinfo ci;
   int nScore, nScoreOpponent;
@@ -425,7 +425,7 @@ ExtEvaluation( extcmd *pec ) {
 static char *
 ExtFIBSBoard( extcmd *pec ) {
 
-  char szName[ 32 ], szOpp[ 32 ];
+  char szName[ MAX_NAME_LEN ], szOpp[ MAX_NAME_LEN ];
   int anBoard[ 2 ][ 25 ], anBoardOrig[ 2 ][ 25 ], nMatchTo, anScore[ 2 ],
     anDice[ 2 ], nCube, fCubeOwner, fDoubled, fTurn, fCrawford,
     anMove[ 8 ];
@@ -604,7 +604,7 @@ extern void CommandExternal( char *sz ) {
 	return;
       }
       
-      while( ( hPeer = accept( h, &saRemote, &saLen ) ) < 0 ) {
+      while( ( hPeer = accept( h, (struct sockaddr*)&saRemote, &saLen ) ) < 0 ) {
 	if( errno == EINTR ) {
           if( fAction )
             fnAction();
