@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gnubgmodule.c,v 1.23 2003/11/29 10:06:51 thyssen Exp $
+ * $Id: gnubgmodule.c,v 1.28 2004/03/15 06:50:11 thyssen Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -337,7 +337,7 @@ PythonCubeInfo(PyObject* self IGNORE, PyObject* args) {
   int anScore[ 2 ] = { ms.anScore[ 0 ], ms.anScore[ 1 ] };
   int fCrawford = ms.fCrawford;
   int fJacoby = ms.fJacoby;
-  int fBeavers = fBeavers;
+  int fBeavers = ms.cBeavers;
   bgvariation bgv = ms.bgv;
 
   if ( ! PyArg_ParseTuple( args, "|iiii(ii)iiii:cubeinfo", 
@@ -356,6 +356,20 @@ PythonCubeInfo(PyObject* self IGNORE, PyObject* args) {
 }
 
 
+static PyObject *
+PythonNextTurn( PyObject *self IGNORE, PyObject *args ) {
+
+  fNextTurn = TRUE;
+  while( fNextTurn ) {
+    if (NextTurn( TRUE ) == -1)
+      fNextTurn = FALSE;
+  }
+
+  return Py_None;
+
+}
+
+
 static PyObject *
 PythonEvalContext( PyObject* self IGNORE, PyObject *args ) {
 
@@ -391,10 +405,9 @@ PythonCommand( PyObject* self IGNORE, PyObject *args ) {
 
   PortableSignal( SIGINT, HandleInterrupt, &sh, FALSE );
   HandleCommand( sz, acTop );
-  fNextTurn = TRUE;
-  while( fNextTurn ) {
-    NextTurn( TRUE );
-  }
+
+  PythonNextTurn(0, 0);
+
   outputx();
   free( sz );
   PortableSignalRestore( SIGINT, &sh );
@@ -516,19 +529,6 @@ METPre( float aar[ MAXSCORE ][ MAXSCORE ], const int n ) {
 }
 
 
-static PyObject *
-PythonNextTurn( PyObject *self IGNORE, PyObject *args ) {
-
-  fNextTurn = TRUE;
-  while( fNextTurn ) {
-    NextTurn( TRUE );
-  }
-
-  return Py_None;
-
-}
-
-
 static PyObject *
 PythonMET( PyObject* self IGNORE, PyObject *args ) {
 
@@ -1977,6 +1977,9 @@ PythonInitialise( const char *argv0, const char *szDir ) {
 
   FILE *pf;
   char *pch;
+  char scriptDir[BIG_PATH];
+  strcpy( scriptDir, ( szDir && *szDir ) ? szDir : "." );
+  strcat(scriptDir, "/scripts");
 
   Py_SetProgramName( (char *) argv0 );
   Py_Initialize();
@@ -1994,7 +1997,7 @@ PythonInitialise( const char *argv0, const char *szDir ) {
 
   /* run gnubg.py start up script */
 
-  if ( ( pch = PathSearch( "gnubg.py", szDir ) ) &&
+  if ( ( pch = PathSearch( "gnubg.py", scriptDir ) ) &&
        ( pf = fopen( pch, "r" ) ) ) {
     PyRun_AnyFile( pf, pch );
   }
