@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkgame.h,v 1.78 2004/01/19 10:20:07 uid68519 Exp $
+ * $Id: gtkgame.h,v 1.81 2004/03/15 12:08:20 Superfly_Jon Exp $
  */
 
 #ifndef _GTKGAME_H_
@@ -145,6 +145,8 @@ extern void GTKSetCube( gpointer *p, guint n, GtkWidget *pw );
 extern void GTKSetDice( gpointer *p, guint n, GtkWidget *pw );
 extern void GTKHelp( char *sz );
 extern void GTKMatchInfo( void );
+extern void GTKShowBuildInfo(void);
+extern void GTKCommandShowCredits(void);
 
 extern void SetEvaluation( gpointer *p, guint n, GtkWidget *pw );
 extern void SetRollouts( gpointer *p, guint n, GtkWidget *pw );
@@ -163,7 +165,7 @@ extern void
 GTKNew ( void );
 
 extern void
-UpdateGeometry ( const gnubgwindow gw );
+setWindowGeometry(windowobject* pwo);
 
 extern void
 RefreshGeometries ( void );
@@ -198,4 +200,6 @@ extern void GTKRemoveTimeControl( char *szName) ;
 extern void GTKCheckTimeControl( char *szName) ;
 #endif
 
+extern void SetToolbarStyle(int value);
+
 #endif
