@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: htmlimages.c,v 1.20 2004/01/06 12:30:36 uid68519 Exp $
+ * $Id: htmlimages.c,v 1.24 2004/03/23 10:15:49 Superfly_Jon Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -87,8 +87,8 @@ unsigned short *asRefract[2];
 
 #if HAVE_LIBART
 unsigned char *auchArrow[ 2 ];
-unsigned char *auchMidlb;
 #endif
+unsigned char *auchMidlb;
 
 static void WriteImageStride(unsigned char* img, int stride, int cx, int cy)
 {
@@ -115,13 +115,14 @@ static void Write(const char* name, unsigned char* img, int cx, int cy)
 	WriteImage(img, cx, cy);
 }
 
-#if HAVE_LIBART
 static void DrawArrow(int side, int player)
 { /* side 0 = left, 1 = right */
 	int x, y;
 	int offset_x = 0;
 
 	memcpy( auchMidlb, auchBoard, BOARD_WIDTH * s * BOARD_HEIGHT * s * 3 );
+
+#if HAVE_LIBART
 	ArrowPosition(side /* rd.fClockwise */, s, &x, &y);
 
 	AlphaBlendClip2( auchMidlb, boardStride,
@@ -134,6 +135,7 @@ static void DrawArrow(int side, int player)
 				0, 0,
 				s * ARROW_WIDTH,
 				s * ARROW_HEIGHT );
+#endif
 
 	sprintf( pchFile, "b-mid%cb-%c.png", side ? 'r' : 'l', player ? 'o' : 'x' );
 	if (side == 1)
@@ -142,7 +144,6 @@ static void DrawArrow(int side, int player)
 	WriteImage(auchMidlb + coord(offset_x, BOARD_HEIGHT / 2 - BOARD_CENTER_HEIGHT / 2),
 				BEAROFF_WIDTH * s, BOARD_CENTER_HEIGHT * s);
 }
-#endif
 
 static void DrawPips(unsigned char *auchDest, int nStride,
 				unsigned char *auchPip, int n)
@@ -228,23 +229,11 @@ static void WriteImages()
 		BAR_WIDTH * s, CUBE_HEIGHT * s);
 
 	/* bearoff tray dividers */
-#if HAVE_LIBART
 	/* 4 arrows, left+right side for each player */
 	DrawArrow(0, 0);
 	DrawArrow(0, 1);
 	DrawArrow(1, 0);
 	DrawArrow(1, 1);
-#else
-	for (i = 0; i < 2; i++)
-	{
-		int offset_x = 0;
-		sprintf( pchFile, "b-midlb-%c.png", i ? 'x' : 'o' );
-		if (i == 1)
-			offset_x = BOARD_WIDTH - BEAROFF_WIDTH;
-		WriteImage(auchBoard + coord(offset_x, BOARD_HEIGHT / 2 - BOARD_CENTER_HEIGHT / 2),
-			BEAROFF_WIDTH * s, BOARD_CENTER_HEIGHT * s);
-	}
-#endif
 
 	/* left bearoff centre */
 	strcpy( pchFile, "b-midlb.png" );
@@ -485,7 +474,7 @@ static void WriteImages()
 		int offset;
 		int cube_y = i ? ((BOARD_HEIGHT - BORDER_HEIGHT) * s - CUBE_HEIGHT * ss) : (BORDER_HEIGHT * s);
 
-		AlphaBlend(auchBoard + (BOARD_WIDTH / 2) * s * 3 - (CUBE_WIDTH / 2) * ss * 3 +
+		AlphaBlendBase(auchBoard + (BOARD_WIDTH / 2) * s * 3 - (CUBE_WIDTH / 2) * ss * 3 +
 				cube_y * boardStride, boardStride,
 				auchBoard + (BOARD_WIDTH / 2) * s * 3 - (CUBE_WIDTH / 2) * ss * 3 +
 				cube_y * boardStride, boardStride,
@@ -527,7 +516,7 @@ static void WriteImages()
 		offset = ((BOARD_CENTER_HEIGHT / 2) * s - (CUBE_HEIGHT / 2) * ss) * BOARD_CENTER_WIDTH * s * 3 +
 			3 * POINT_WIDTH * s * 3 - (CUBE_WIDTH / 2) * ss * 3;
 
-		AlphaBlend(auchMidBoard + offset, BOARD_CENTER_WIDTH * s * 3,
+		AlphaBlendBase(auchMidBoard + offset, BOARD_CENTER_WIDTH * s * 3,
 				auchMidBoard + offset, BOARD_CENTER_WIDTH * s * 3,
 				auchCube, CUBE_WIDTH * ss * 4,
 				CUBE_WIDTH * ss, CUBE_HEIGHT * ss);
@@ -549,7 +538,7 @@ static void WriteImages()
 		}
 	}
 	/* cube - centered */
-	AlphaBlend( auchBoard + 
+	AlphaBlendBase( auchBoard + 
 				((BOARD_HEIGHT / 2) * s - (CUBE_HEIGHT / 2) * ss) * boardStride +
 				(BOARD_WIDTH / 2) * s * 3 - (CUBE_WIDTH / 2) * ss * 3, 
 				boardStride,
@@ -590,12 +579,12 @@ static void WriteImages()
 
 		int dice_y = ((BOARD_HEIGHT / 2) * s - (DIE_HEIGHT / 2) * ss) * boardStride;
 
-		AlphaBlend(auchBoard + dice_x - DIE_WIDTH * ss * 3 + dice_y, boardStride, 
+		AlphaBlendBase(auchBoard + dice_x - DIE_WIDTH * ss * 3 + dice_y, boardStride, 
 							auchBoard + dice_x - DIE_WIDTH * ss * 3 + dice_y, boardStride,
 							auchDice[i], DIE_WIDTH * ss * 4,
 							DIE_WIDTH * ss, DIE_HEIGHT * ss);
 
-		AlphaBlend(auchBoard + dice_x + DIE_WIDTH * ss * 3 + dice_y, boardStride,
+		AlphaBlendBase(auchBoard + dice_x + DIE_WIDTH * ss * 3 + dice_y, boardStride,
 							auchBoard + dice_x + DIE_WIDTH * ss * 3 + dice_y, boardStride,
 							auchDice[i], DIE_WIDTH * ss * 4,
 							DIE_WIDTH * ss, DIE_HEIGHT * ss);
@@ -704,8 +693,8 @@ static void AllocObjects()
 
 	s = exsExport.nHtmlSize;
 
-#if HAVE_LIBART
 	auchMidlb = malloc((BOARD_WIDTH * s * 3 * BOARD_HEIGHT * s) * sizeof(char));
+#if HAVE_LIBART
 	for (i = 0; i < 2; i++)
 		auchArrow[i] = art_new( art_u8, s * ARROW_WIDTH * 4 * s * ARROW_HEIGHT );
 #endif
@@ -742,8 +731,8 @@ static void AllocObjects()
 static void TidyObjects()
 {
 	int i, j, k;
-#if HAVE_LIBART
 	free(auchMidlb);
+#if HAVE_LIBART
 	for (i = 0; i < 2; i++)
 		art_free( auchArrow[ i ] );
 #endif /* HAVE_LIBART */
@@ -777,7 +766,7 @@ static void TidyObjects()
 		free(asRefract[i]);
 }
 
-extern void CommandExportHTMLImages(char *sz)
+extern void CommandExportHTMLImages( char *sz )
 {
 	szFile = GetFilenameBase(sz);
 	if (!szFile)
@@ -791,10 +780,10 @@ extern void CommandExportHTMLImages(char *sz)
 	TidyObjects();
 }
 
-#else
-extern void CommandExportHTMLImages( char * )
+#else /* not HAVE_LIBPNG */
+extern void CommandExportHTMLImages( char *sz )
 {
 	outputl( _("This installation of GNU Backgammon was compiled without\n"
 		"support for writing HTML images.") );
 }
-#endif
+#endif /* not HAVE_LIBPNG */
