@@ -1,7 +1,7 @@
 /*
  * latex.c
  *
- * by Gary Wong <gtw@gnu.org>, 2001
+ * by Gary Wong <gtw@gnu.org>, 2001, 2002
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: latex.c,v 1.7 2001/11/01 15:47:56 gtw Exp $
+ * $Id: latex.c,v 1.30 2003/11/29 14:08:46 thyssen Exp $
  */
 
 #include "config.h"
@@ -24,8 +24,12 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "analysis.h"
 #include "backgammon.h"
 #include "drawboard.h"
+#include "export.h"
+#include "format.h"
+#include "i18n.h"
 
 static char*aszLuckTypeLaTeXAbbr[] = { "$--$", "$-$", "", "$+$", "$++$" };
 
@@ -35,11 +39,11 @@ static void Points1_12( FILE *pf, int y ) {
 
     if( fClockwise )
 	for( i = 1; i <= 12; i++ )
-	    fprintf( pf, "\\put(%d,%d){\\makebox(20,10){\\textsf{%d}}}\n",
+	    fprintf( pf, "\\put(%d,%d){\\makebox(20,10){\\textsl{\\tiny %d}}}\n",
 		     50 + i * 20 + ( i > 6 ) * 20, y, i );
     else
 	for( i = 1; i <= 12; i++ )
-	    fprintf( pf, "\\put(%d,%d){\\makebox(20,10){\\textsf{%d}}}\n",
+	    fprintf( pf, "\\put(%d,%d){\\makebox(20,10){\\textsl{\\tiny %d}}}\n",
 		     330 - i * 20 - ( i > 6 ) * 20, y, i );
 }
 
@@ -49,18 +53,19 @@ static void Points13_24( FILE *pf, int y ) {
     
     if( fClockwise )
 	for( i = 13; i <= 24; i++ )
-	    fprintf( pf, "\\put(%d,%d){\\makebox(20,10){\\textsf{%d}}}\n",
+	    fprintf( pf, "\\put(%d,%d){\\makebox(20,10){\\textsl{\\tiny %d}}}\n",
 		     570 - i * 20 - ( i > 18 ) * 20, y, i );
     else
 	for( i = 13; i <= 24; i++ )
-	    fprintf( pf, "\\put(%d,%d){\\makebox(20,10){\\textsf{%d}}}\n",
+	    fprintf( pf, "\\put(%d,%d){\\makebox(20,10){\\textsl{\\tiny %d}}}\n",
 		     i * 20 - 190 + ( i > 18 ) * 20, y, i );
 }
 
 static void LaTeXPrologue( FILE *pf ) {
 
     fputs( "\\documentclass{article}\n"
-	   "\\usepackage{epic,eepic,textcomp}\n"
+	   "\\usepackage{epic,eepic,textcomp,ucs}\n"
+	   "\\usepackage[utf8]{inputenc}\n"
 	   "\\newcommand{\\board}{\n"
 	   "\\shade\\path(70,20)(80,120)(90,20)(110,20)(120,120)(130,20)"
 	   "(150,20)(160,120)\n"
@@ -106,6 +111,7 @@ static void LaTeXPrologue( FILE *pf ) {
 	   "\\addtolength\\oddsidemargin{-72pt}\n"
 	   "\\addtolength\\evensidemargin{-72pt}\n"
 	   "\\addtolength\\topmargin{-72pt}\n\n"
+           "\\setlength{\\unitlength}{0.20mm}\n\n"  /* user should set size */
 	   "\\begin{document}\n", pf );
 
     /* FIXME define commands for \cubetext, \labeltext, etc. here, which
@@ -120,7 +126,7 @@ static void LaTeXEpilogue( FILE *pf ) {
 
 static void DrawLaTeXPoint( FILE *pf, int i, int fPlayer, int c ) {
 
-    int j, x, y;
+    int j, x, y = 0;
 
     if( i < 6 )
 	x = 320 - 20 * i;
@@ -142,7 +148,7 @@ static void DrawLaTeXPoint( FILE *pf, int i, int fPlayer, int c ) {
 	if( j == 5 || ( i == 24 && j == 3 ) ) {
 	    fprintf( pf, "\\whiten\\path(%d,%d)(%d,%d)(%d,%d)(%d,%d)(%d,%d)\n"
 		     "\\path(%d,%d)(%d,%d)(%d,%d)(%d,%d)(%d,%d)\n"
-		     "\\put(%d,%d){\\makebox(10,10){\\textsf{%d}}}\n",
+		     "\\put(%d,%d){\\makebox(10,10){\\textsf{\\tiny %d}}}\n",
 		     x - 5, y - 5, x + 5, y - 5, x + 5, y + 5, x - 5, y + 5,
 		     x - 5, y - 5,
 		     x - 5, y - 5, x + 5, y - 5, x + 5, y + 5, x - 5, y + 5,
@@ -201,7 +207,7 @@ static void PrintLaTeXBoard( FILE *pf, matchstate *pms, int fPlayer ) {
 	y = 230;
 
     fprintf( pf, "\\path(%d,%d)(%d,%d)(%d,%d)(%d,%d)(%d,%d)"
-	     "\\put(%d,%d){\\makebox(24,24){\\textsf{\\LARGE %d}}}\n",
+	     "\\put(%d,%d){\\makebox(24,24){\\textsf{\\large %d}}}\n",
 	     x - 12, y - 12, x + 12, y - 12, x + 12, y + 12, x - 12, y + 12,
 	     x - 12, y - 12, x - 12, y - 12,
 	     pms->nCube == 1 ? 64 : pms->nCube );
@@ -209,8 +215,8 @@ static void PrintLaTeXBoard( FILE *pf, matchstate *pms, int fPlayer ) {
     fputs( "\\end{picture}\\end{center}\\vspace{-4mm}\n\n\\nopagebreak[4]\n",
 	   pf );
 }
-
-static void PrintLaTeXComment( FILE *pf, unsigned char *pch ) {
+#if 0
+static void LaTeXEscape( FILE *pf, unsigned char *pch ) {
 
     /* Translation table from GNU recode, by Franois Pinard. */
     static struct translation {
@@ -332,30 +338,40 @@ static void PrintLaTeXComment( FILE *pf, unsigned char *pch ) {
 	    }
 	pch++;
     }
+}
+#endif
 
+static void PrintLaTeXComment( FILE *pf, unsigned char *pch ) {
+
+    /* LaTeXEscape( pf, pch ); */
+    if( pch != NULL)
+        fputs( pch, pf );
     fputs( "\n\n", pf );
 }
 
-static void PrintLaTeXCubeAnalysis( FILE *pf, matchstate *pms, int fPlayer,
-				    float arDouble[ 4 ], evalsetup *pes ) { 
+static void 
+PrintLaTeXCubeAnalysis( FILE *pf, const matchstate* pms, int fPlayer,
+                        const float aarOutput[ 2 ][ NUM_ROLLOUT_OUTPUTS ], 
+                        const float aarStdDev[ 2 ][ NUM_ROLLOUT_OUTPUTS ], 
+                        const evalsetup *pes ) { 
+  
     cubeinfo ci;
-    char sz[ 1024 ];
 
     if( pes->et == EVAL_NONE )
 	return;
-    
+
     SetCubeInfo( &ci, pms->nCube, pms->fCubeOwner, fPlayer, pms->nMatchTo,
-		 pms->anScore, pms->fCrawford, fJacoby, nBeavers );
+		 pms->anScore, pms->fCrawford, pms->fJacoby, nBeavers,
+                 pms->bgv );
     
     if( !GetDPEq( NULL, NULL, &ci ) )
 	/* No cube action possible */
 	return;
     
-    GetCubeActionSz( arDouble, sz, &ci, fOutputMWC, FALSE );
-
+    
     /* FIXME use center and tabular environment instead of verbatim */
     fputs( "{\\begin{quote}\\footnotesize\\begin{verbatim}\n", pf );
-    fputs( sz, pf );
+    fputs( OutputCubeAnalysis( aarOutput, aarStdDev, pes, &ci ), pf );
     fputs( "\\end{verbatim}\\end{quote}}\n", pf );    
 }
 
@@ -372,14 +388,39 @@ static void ExportGameLaTeX( FILE *pf, list *plGame ) {
     int fTook = FALSE, i;
     char sz[ 1024 ];
 
+    updateStatisticsGame ( plGame );
+
     for( pl = plGame->plNext; pl != plGame; pl = pl->plNext ) {
 	pmr = pl->p;
+        FixMatchState ( &msExport, pmr );
 	switch( pmr->mt ) {
 	case MOVE_GAMEINFO:
-	    /* FIXME game introduction */
+            fputs ( "\\noindent{\\Large ", pf );
+	    if( pmr->g.nMatch )
+		fprintf( pf, _("%d point match (game %d)"), 
+                         pmr->g.nMatch, pmr->g.i + 1);
+	    else
+		fprintf( pf, _("Money session (game %d)"), 
+                         pmr->g.i + 1 );
+
+            fputs ( "}\n\n", pf );
+
+	    fprintf( pf, "\\noindent\n\\makebox[0.5\\textwidth][s]"
+		     "{\\large %s ", PlayerSymbol( 0 ) );
+	    fputs( ap[ 0 ].szName, pf );
+/*	    LaTeXEscape( pf, ap[ 0 ].szName ); */
+	    fprintf( pf, " (%d points)\\hfill}", pmr->g.anScore[ 0 ] );
+	    
+	    fprintf( pf, "\\makebox[0.5\\textwidth][s]"
+		     "{\\large %s ", PlayerSymbol( 1 ) );
+	    fputs( ap[ 1 ].szName, pf );
+/*	    LaTeXEscape( pf, ap[ 1 ].szName ); */
+	    fprintf( pf, " (%d points)\\hfill}\n\n", pmr->g.anScore[ 1 ] );
+	    	    
 	    break;
 	    
 	case MOVE_NORMAL:
+	    msExport.fTurn = msExport.fMove = pmr->n.fPlayer;
 	    if( fTook )
 		/* no need to print board following a double/take */
 		fTook = FALSE;
@@ -387,14 +428,17 @@ static void ExportGameLaTeX( FILE *pf, list *plGame ) {
 		PrintLaTeXBoard( pf, &msExport, pmr->n.fPlayer );
 	    
 	    PrintLaTeXCubeAnalysis( pf, &msExport, pmr->n.fPlayer,
-				    pmr->n.arDouble, &pmr->n.esDouble );
+				    GCCCONSTAHACK pmr->n.aarOutput,
+				    GCCCONSTAHACK pmr->n.aarStdDev,
+                                    &pmr->n.esDouble );
+            /* FIXME: output cube skill */
 
 	    sprintf( sz, "%s %d%d%s: ", PlayerSymbol( pmr->n.fPlayer ),
 		     pmr->n.anRoll[ 0 ], pmr->n.anRoll[ 1 ],
 		     aszLuckTypeLaTeXAbbr[ pmr->n.lt ] );
 	    FormatMove( strchr( sz, 0 ), msExport.anBoard, pmr->n.anMove );
 	    fprintf( pf, "\\begin{center}%s%s\\end{center}\n\n", sz,
-		     aszSkillTypeAbbr[ pmr->n.st ] );
+		     aszSkillTypeAbbr[ pmr->n.stMove ] );
 
 	    /* FIXME use center and tabular environment instead of verbatim */
 	    fputs( "{\\footnotesize\\begin{verbatim}\n", pf );
@@ -404,9 +448,9 @@ static void ExportGameLaTeX( FILE *pf, list *plGame ) {
 		    continue;
 
 		putc( i == pmr->n.iMove ? '*' : ' ', pf );
-		FormatMoveHint( sz, msExport.anBoard, &pmr->n.ml, i,
+		FormatMoveHint( sz, &msExport, &pmr->n.ml, i,
 				i != pmr->n.iMove ||
-				i != pmr->n.ml.cMoves - 1 );
+				i != pmr->n.ml.cMoves - 1, TRUE, TRUE );
 		fputs( sz, pf );
 	    }
 	    fputs( "\\end{verbatim}}", pf );    
@@ -418,12 +462,15 @@ static void ExportGameLaTeX( FILE *pf, list *plGame ) {
 	case MOVE_DOUBLE:
 	    PrintLaTeXBoard( pf, &msExport, pmr->d.fPlayer );
 
-	    PrintLaTeXCubeAnalysis( pf, &msExport, pmr->d.fPlayer,
-				    pmr->d.arDouble, &pmr->d.esDouble );
+	    PrintLaTeXCubeAnalysis(pf, &msExport, pmr->d.fPlayer,
+				   GCCCONSTAHACK pmr->d.CubeDecPtr->aarOutput, 
+				   GCCCONSTAHACK pmr->d.CubeDecPtr->aarStdDev, 
+				   &pmr->d.CubeDecPtr->esDouble );
 
 	    /* FIXME what about beavers? */
-	    fprintf( pf, "\\begin{center}%s Double%s\\end{center}\n\n",
+	    fprintf( pf, "\\begin{center}%s %s%s\\end{center}\n\n",
 		     PlayerSymbol( pmr->d.fPlayer ),
+                     _("Double"),
 		     aszSkillTypeAbbr[ pmr->d.st ] );
 	    
 	    PrintLaTeXComment( pf, pmr->a.sz );
@@ -432,8 +479,9 @@ static void ExportGameLaTeX( FILE *pf, list *plGame ) {
 	    
 	case MOVE_TAKE:
 	    fTook = TRUE;
-	    fprintf( pf, "\\begin{center}%s Take%s\\end{center}\n\n",
+	    fprintf( pf, "\\begin{center}%s %s%s\\end{center}\n\n",
 		     PlayerSymbol( pmr->d.fPlayer ),
+                     _("Take"),
 		     aszSkillTypeAbbr[ pmr->d.st ] );
 
 	    PrintLaTeXComment( pf, pmr->a.sz );
@@ -441,8 +489,9 @@ static void ExportGameLaTeX( FILE *pf, list *plGame ) {
 	    break;
 	    
 	case MOVE_DROP:
-	    fprintf( pf, "\\begin{center}%s Drop%s\\end{center}\n\n",
+	    fprintf( pf, "\\begin{center}%s %s%s\\end{center}\n\n",
 		     PlayerSymbol( pmr->d.fPlayer ),
+                     _("Drop"),
 		     aszSkillTypeAbbr[ pmr->d.st ] );
 
 	    PrintLaTeXComment( pf, pmr->a.sz );
@@ -450,9 +499,10 @@ static void ExportGameLaTeX( FILE *pf, list *plGame ) {
 	    break;
 	    
 	case MOVE_RESIGN:
-	    fprintf( pf, "\\begin{center}%s Resigns %s\\end{center}\n\n",
+	    fprintf( pf, "\\begin{center}%s %s %s\\end{center}\n\n",
 		     PlayerSymbol( pmr->r.fPlayer ),
-		     aszGameResult[ pmr->r.nResigned - 1 ] );
+                     _("Resigns"),
+		     gettext ( aszGameResult[ pmr->r.nResigned - 1 ]  ) );
 	    /* FIXME print resignation analysis, if available */
 	    PrintLaTeXComment( pf, pmr->a.sz );
 	    break;
@@ -460,6 +510,10 @@ static void ExportGameLaTeX( FILE *pf, list *plGame ) {
 	case MOVE_SETDICE:
 	    /* ignore */
 	    break;
+
+	case MOVE_TIME:
+		/* ignore */
+		break;
 	    
 	case MOVE_SETBOARD:
 	case MOVE_SETCUBEVAL:
@@ -468,10 +522,10 @@ static void ExportGameLaTeX( FILE *pf, list *plGame ) {
 	    break;
 	}
 
-	ApplyMoveRecord( &msExport, pmr );
+	ApplyMoveRecord( &msExport, plGame, pmr );
     }
     
-    if( ( GameStatus( msExport.anBoard ) ) )
+    if( ( GameStatus( msExport.anBoard, msExport.bgv ) ) )
 	/* FIXME print game result */
 	;
 }
@@ -483,20 +537,23 @@ extern void CommandExportGameLaTeX( char *sz ) {
     sz = NextToken( &sz );
     
     if( !plGame ) {
-	outputl( "No game in progress (type `new game' to start one)." );
+	outputl( _("No game in progress (type `new game' to start one).") );
 	return;
     }
     
+    if ( ! confirmOverwrite ( sz, fConfirmSave ) )
+      return;
+
     if( !sz || !*sz ) {
-	outputl( "You must specify a file to export to (see `help export"
-		 "game latex')." );
+	outputl( _("You must specify a file to export to (see `help export "
+		 "game latex').") );
 	return;
     }
 
     if( !strcmp( sz, "-" ) )
 	pf = stdout;
     else if( !( pf = fopen( sz, "w" ) ) ) {
-	perror( sz );
+	outputerr( sz );
 	return;
     }
 
@@ -508,6 +565,9 @@ extern void CommandExportGameLaTeX( char *sz ) {
     
     if( pf != stdout )
 	fclose( pf );
+
+    setDefaultFileName ( sz, PATH_LATEX );
+
 }
 
 extern void CommandExportMatchLaTeX( char *sz ) {
@@ -518,15 +578,18 @@ extern void CommandExportMatchLaTeX( char *sz ) {
     sz = NextToken( &sz );
     
     if( !sz || !*sz ) {
-	outputl( "You must specify a file to export to (see `help export "
-		 "match latex')." );
+	outputl( _("You must specify a file to export to (see `help export "
+		 "match latex').") );
 	return;
     }
 
+    if ( ! confirmOverwrite ( sz, fConfirmSave ) )
+      return;
+
     if( !strcmp( sz, "-" ) )
 	pf = stdout;
     else if( !( pf = fopen( sz, "w" ) ) ) {
-	perror( sz );
+	outputerr( sz );
 	return;
     }
 
@@ -541,4 +604,7 @@ extern void CommandExportMatchLaTeX( char *sz ) {
     
     if( pf != stdout )
 	fclose( pf );
+
+    setDefaultFileName ( sz, PATH_LATEX );
+
 }
