@@ -11,7 +11,7 @@ typedef int ( *hashcomparefunc )( void *p0, void *p1 );
 
 typedef struct _hashnode {
     struct _hashnode *phnNext;
-    long l;
+    unsigned long l;
     void *p;
 } hashnode;
 
@@ -19,6 +19,7 @@ typedef struct _hash {
     hashnode **aphn;
     int c, icp;
     hashcomparefunc phcf;
+    unsigned long int cSize, cHits, cMisses, cLookups;
 } hash;
 
 extern int HashCreate( hash *ph, int c, hashcomparefunc phcf );
