@@ -19,7 +19,7 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* $Id: matchequity.c,v 1.40 2003/09/05 20:46:44 thyssen Exp $
+* $Id: matchequity.c,v 1.44 2004/03/25 20:24:42 thyssen Exp $
 */
 
 #include <stdio.h>
@@ -765,7 +765,8 @@ GetDoublePointDeadCube ( float arOutput [ 5 ], cubeinfo *pci ) {
 
 /* 
  * Extend match equity table to MAXSCORE using
- * David Montgomery's extrapolation algorithm.
+ * David Montgomery's extension algorithm. The formula
+ * is independent of the values for score < nMaxScore.
  *
  * Input:
  *    nMaxScore: the length of the native met
@@ -1571,13 +1572,11 @@ getGammonPrice ( float arGammonPrice[ 4 ],
   if ( arGammonPrice[ 3 ] <= 0 )
     arGammonPrice[ 3 ] = 0.0;
 
-#define NDEBUG
   assert( arGammonPrice[ 0 ] >= 0 );
   assert( arGammonPrice[ 1 ] >= 0 );
   assert( arGammonPrice[ 2 ] >= 0 );
   assert( arGammonPrice[ 3 ] >= 0 );
-#undef NDEBUG
-  
+
 }
 
 /*
