@@ -1,7 +1,7 @@
 /*
  * postscript.c
  *
- * by Gary Wong <gtw@gnu.org>, 2001
+ * by Gary Wong <gtw@gnu.org>, 2001, 2002
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: postscript.c,v 1.8 2001/11/01 15:47:56 gtw Exp $
+ * $Id: postscript.c,v 1.37 2003/09/12 14:42:17 Superfly_Jon Exp $
  */
 
 #include "config.h"
@@ -25,14 +25,60 @@
 #include <ctype.h>
 #include <dynarray.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <time.h>
 
+#include "analysis.h"
 #include "backgammon.h"
 #include "drawboard.h"
+#include "positionid.h"
+#include "i18n.h"
+#include "format.h"
+#include "export.h"
+#include "matchid.h"
 
-typedef enum _font { FONT_NONE, FONT_RM, FONT_SF, FONT_TT } font;
-static char *aszFont[ FONT_TT + 1 ] = { NULL, "rm", "sf", "tt" };
+typedef enum _font { 
+  FONT_NONE, 
+  /* Times-Roman */
+  FONT_RM,               
+  FONT_RM_BOLD,          
+  FONT_RM_ITALIC,       
+  FONT_RM_BOLD_ITALIC,  
+  /* Helvetica (Sans serif) */
+  FONT_SF,  
+  FONT_SF_BOLD,  
+  FONT_SF_OBLIQUE,  
+  FONT_SF_BOLD_OBLIQUE,  
+  /* Courier (type writer) */
+  FONT_TT,  
+  FONT_TT_BOLD,
+  FONT_TT_OBLIQUE,
+  FONT_TT_BOLD_OBLIQUE,
+  NUM_FONTS,
+} font;
+static char *aszFont[ NUM_FONTS ] = { 
+  NULL, 
+  "rm", "rmb", "rmi", "rmbi",
+  "sf", "sfb", "sfo", "sfbo",
+  "tt", "ttb", "tto", "ttbo",
+};
+
+static char *aszFontName[ NUM_FONTS ] = {
+  NULL,
+  "Times-Roman",
+  "Times-Bold",
+  "Times-Italic",
+  "Times-BoldItalic",
+  "Helvetica",
+  "Helvetica-Bold",
+  "Helvetica-Oblique",
+  "Helvetica-Bold-Oblique",
+  "Courier",
+  "Courier-Bold",
+  "Courier-Oblique",
+  "Courier-Bold-Oblique" 
+};
 
 /* Output settings.  FIXME there should be commands to modify these! */
 static int cxPage = 595, cyPage = 842; /* A4 -- min (451,648) */
@@ -40,7 +86,7 @@ static int nMag = 100; /* Board scale (percentage) -- min 1, max 127 */
 
 /* Current document state. */
 static int iPage, y, nFont, fPDF, idPages, idResources, idLength,
-    aidFont[ FONT_TT + 1 ];
+    aidFont[ NUM_FONTS ];
 static long lStreamStart;
 static font fn;
 static dynarray daXRef, daPages;
@@ -68,8 +114,12 @@ static void EndObject( FILE *pf ) {
     fputs( "endobj\n", pf );
 }
 
-static void PostScriptEscape( FILE *pf, char *pch ) {
+static void PostScriptEscape( FILE *pf, unsigned char *pchIn ) {
 
+    unsigned char *pch, *sz;
+
+    pch = sz = Convert( pchIn, "ISO-8859-1", GNUBG_CHARSET );
+    
     while( *pch ) {
 	switch( *pch ) {
 	case '\\':
@@ -83,16 +133,18 @@ static void PostScriptEscape( FILE *pf, char *pch ) {
 	    break;
 	default:
 	    if( (unsigned char) *pch >= 0x80 )
-		fprintf( pf, "\\%030o", *pch );
+		fprintf( pf, "\\%03o", *pch );
 	    else
 		putc( *pch, pf );
 	    break;
 	}
 	pch++;
     }
+
+    free( sz );
 }
 
-static void StartPage( FILE *pf ) {
+static void PSStartPage( FILE *pf ) {
 
     iPage++;
     fn = FONT_NONE;
@@ -128,7 +180,7 @@ static void StartPage( FILE *pf ) {
 		 ( cxPage - 451 ) / 2, ( cyPage - 648 ) / 2 );
 }
 
-static void EndPage( FILE *pf ) {
+static void PSEndPage( FILE *pf ) {
 
     if( fPDF ) {
 	long cb;
@@ -176,8 +228,8 @@ static void Ensure( FILE *pf, int cy ) {
     assert( cy <= 648 );
     
     if( y < cy ) {
-	EndPage( pf );
-	StartPage( pf );
+	PSEndPage( pf );
+	PSStartPage( pf );
     }
 }
 
@@ -197,18 +249,20 @@ static void Advance( FILE *pf, int cy ) {
 static void Skip( FILE *pf, int cy ) {
 
     if( y < cy ) {
-	EndPage( pf );
-	StartPage( pf );
+	PSEndPage( pf );
+	PSStartPage( pf );
     } else if( y != 648 )
 	Consume( pf, cy );
 }
 
-static void PostScriptPrologue( FILE *pf ) {
+static void PostScriptPrologue( FILE *pf, int fEPS, char *szTitle ) {
 
     /* FIXME change the font-setting procedures to use ISO 8859-1
        encoding */
+   
+    int i;
     
-    static char szPrologue[] =
+    static char *aszPrologue[] = {
 	"%%%%Creator: (GNU Backgammon " VERSION ")\n"
 	"%%%%DocumentData: Clean7Bit\n"
 	"%%%%DocumentNeededResources: font Courier Helvetica Times-Roman\n"
@@ -219,14 +273,11 @@ static void PostScriptPrologue( FILE *pf ) {
 	"%%%%PageOrder: Ascend\n"
 	"%%%%EndComments\n"
 	"%%%%BeginDefaults\n"
-	"%%%%PageResources: font Courier Helvetica Times-Roman\n"
+        "%%%%PageResources: font Courier Helvetica Times-Roman\n"
 	"%%%%EndDefaults\n"
 	"%%%%BeginProlog\n"
 	"%%%%BeginResource: procset GNU-Backgammon-Prolog 1.0 0\n"
-	"\n"
-	"/rm { /Times-Roman findfont exch scalefont setfont } bind def\n"
-	"/sf { /Helvetica findfont exch scalefont setfont } bind def\n"
-	"/tt { /Courier findfont exch scalefont setfont } bind def\n"
+	"\n",
 	"\n"
 	"/cshow { dup stringwidth pop 2 div neg 0 rmoveto show } bind def\n"
 	"\n"
@@ -309,7 +360,7 @@ static void PostScriptPrologue( FILE *pf ) {
 	"%%%%IncludeResource: font Courier\n"
 	"%%%%IncludeResource: font Helvetica\n"
 	"%%%%IncludeResource: font Times-Roman\n"
-	"%%%%EndSetup\n";
+	"%%%%EndSetup\n" };
     time_t t;
     char *sz, *pch;
 
@@ -332,50 +383,49 @@ static void PostScriptPrologue( FILE *pf ) {
 		 idPages = AllocateObject() );
 	EndObject( pf );
 
-	StartObject( pf, aidFont[ FONT_RM ] = AllocateObject() );
-	fputs( "<<\n"
-	       "/Type /Font\n"
-	       "/Subtype /Type1\n"
-	       "/Name /rm\n"
-	       "/BaseFont /Times-Roman\n"
-	       "/Encoding /WinAnsiEncoding\n"
-	       ">>\n", pf );
-	EndObject( pf );
-	
-	StartObject( pf, aidFont[ FONT_SF ] = AllocateObject() );
-	fputs( "<<\n"
-	       "/Type /Font\n"
-	       "/Subtype /Type1\n"
-	       "/Name /sf\n"
-	       "/BaseFont /Helvetica\n"
-	       "/Encoding /WinAnsiEncoding\n"
-	       ">>\n", pf );
-	EndObject( pf );
-	
-	StartObject( pf, aidFont[ FONT_TT ] = AllocateObject() );
-	fputs( "<<\n"
-	       "/Type /Font\n"
-	       "/Subtype /Type1\n"
-	       "/Name /tt\n"
-	       "/BaseFont /Courier\n"
-	       "/Encoding /WinAnsiEncoding\n"
-	       ">>\n", pf );
-	EndObject( pf );
+        /* fonts */
+
+        for ( i = 1; i < NUM_FONTS; ++i ) {
+
+          StartObject ( pf, aidFont[ i ] = AllocateObject() );
+
+          fprintf ( pf,
+                    "<<\n"
+                    "/Type /Font\n"
+                    "/Subtype /Type1\n"
+                    "/Name /%s\n"
+                    "/BaseFont /%s\n"
+                    "/Encoding /WinAnsiEncoding\n"
+                    ">>\n", aszFont[ i ], aszFontName[ i ] );
+          EndObject( pf );
+
+        }
 	
 	StartObject( pf, idResources = AllocateObject() );
 	fprintf( pf, "<<\n"
 		 "/ProcSet [/PDF /Text]\n"
-		 "/Font << /rm %d 0 R /sf %d 0 R /tt %d 0 R >>\n"
-		 ">>\n", aidFont[ FONT_RM ], aidFont[ FONT_SF ],
-		 aidFont[ FONT_TT ] );
+		 "/Font << " );
+
+        for ( i = 1; i < NUM_FONTS; ++i ) 
+          fprintf ( pf, "/%s %d 0 R ", aszFont[ i ], aidFont[ i ] );
+
+        fprintf ( pf, ">>\n" ">>\n" );
+
 	/* FIXME list xobject resources */
 	EndObject( pf );
     } else {
 	fputs( "%!PS-Adobe-3.0\n", pf );
 
-	fprintf( pf, "%%%%BoundingBox: %d %d %d %d\n",
-		 ( cxPage - 451 ) / 2, ( cyPage - 648 ) / 2,
-		 ( cxPage + 451 ) / 2, ( cyPage + 648 ) / 2 );
+	if( fEPS )
+	    fprintf( pf, "%%%%BoundingBox: %d %d %d %d\n",
+		     ( cxPage - 451 ) / 2 + 225 - 200 * nMag / 100,
+		     ( cyPage + 648 ) / 2 - 260 * nMag / 100,
+		     ( cxPage - 451 ) / 2 + 225 + 200 * nMag / 100,
+		     ( cyPage + 648 ) / 2 );
+	else
+	    fprintf( pf, "%%%%BoundingBox: %d %d %d %d\n",
+		     ( cxPage - 451 ) / 2, ( cyPage - 648 ) / 2,
+		     ( cxPage + 451 ) / 2, ( cyPage + 648 ) / 2 );
 	
 	time( &t );
 	sz = ctime( &t );
@@ -384,23 +434,31 @@ static void PostScriptPrologue( FILE *pf ) {
 	fprintf( pf, "%%%%CreationDate: (%s)\n", sz );
 	
 	fputs( "%%Title: (", pf );
-	PostScriptEscape( pf, ap[ 0 ].szName );
-	fputs( " vs. ", pf );
-	PostScriptEscape( pf, ap[ 1 ].szName );
+	PostScriptEscape( pf, szTitle );
 	fputs( ")\n", pf );
+
+        /* Prologue */
+
+        fputs ( aszPrologue[ 0 ], pf );
+
+        /* fonts */
+
+        for ( i = 1; i < NUM_FONTS; ++i ) 
+          fprintf ( pf, "/%s { /%s findfont exch scalefont setfont } "
+                    "bind def\n", aszFont[ i ], aszFontName[ i ] );
 	
-	fprintf( pf, szPrologue, fClockwise ? -20 : 20,
+	fprintf( pf, aszPrologue[ 1 ], fClockwise ? -20 : 20,
 		 fClockwise ? 320 : 80, fClockwise ? 365 : 35 );
     }
     
     iPage = 0;
     
-    StartPage( pf );
+    PSStartPage( pf );
 }
 
 static void DrawPostScriptPoint( FILE *pf, int i, int fPlayer, int c ) {
 
-    int j, x, y;
+    int j, x, y = 0;
 
     if( i < 6 )
 	x = 320 - 20 * i;
@@ -454,6 +512,66 @@ static void DrawPostScriptPoint( FILE *pf, int i, int fPlayer, int c ) {
     }
 }
 
+static void
+PostScriptPositionID ( FILE *pf, matchstate *pms ) {
+
+  int anBoard[ 2 ][ 25 ];
+
+  memcpy ( anBoard, pms->anBoard, sizeof ( anBoard ) );
+
+  if ( ! pms->fMove )
+    SwapSides ( anBoard );
+
+  RequestFont ( pf, FONT_RM, 10 );
+  fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (" : "%d %d moveto (", 
+           285 - 200 * nMag / 100, y );
+  fputs ( _("Position ID:"), pf );
+  fputc ( ' ', pf );
+  fputs( fPDF ? ") Tj\n" : ") show\n", pf );
+
+  RequestFont ( pf, FONT_TT, 10 );
+  fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (" : "%d %d moveto (", 
+           285 - 200 * nMag / 100 + 55, y );
+  fputs ( PositionID ( anBoard ), pf );
+  fputs( fPDF ? ") Tj\n" : ") show\n", pf );
+
+  RequestFont ( pf, FONT_RM, 10 );
+  fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (" : "%d %d moveto (", 
+           285 - 200 * nMag / 100 + 160, y );
+  fputs ( _("Match ID:"), pf );
+  fputs( fPDF ? ") Tj\n" : ") show\n", pf );
+
+  RequestFont ( pf, FONT_TT, 10 );
+  fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (" : "%d %d moveto (", 
+           285 - 200 * nMag / 100 + 205, y );
+  fputs ( MatchIDFromMatchState ( pms ), pf );
+  fputs( fPDF ? ") Tj\n" : ") show\n", pf );
+
+}
+
+static void
+PostScriptPipCounts ( FILE *pf, int anBoard[ 2 ][ 25 ], int fMove ) {
+
+  int an[ 2 ][ 25 ];
+  int anPips[ 2 ];
+
+  memcpy ( an, anBoard, sizeof ( an ) );
+
+  if ( ! fMove )
+    SwapSides ( an );
+
+  PipCount ( an, anPips );
+
+  Advance ( pf, 10 );
+  RequestFont ( pf, FONT_RM, 10 );
+  fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (" : "%d %d moveto (", 
+           285 - 200 * nMag / 100, y );
+  fprintf ( pf, _("Pip counts: %s %d, %s %d"), 
+            ap[ 0 ].szName, anPips[ 0 ], ap[ 1 ].szName, anPips[ 1 ] );
+  fputs( fPDF ? ") Tj\n" : ") show\n", pf );
+
+}
+
 static void PrintPostScriptBoard( FILE *pf, matchstate *pms, int fPlayer ) {
 
     int yCube, theta, cos, sin, anOff[ 2 ] = { 15, 15 }, i;
@@ -474,14 +592,14 @@ static void PrintPostScriptBoard( FILE *pf, matchstate *pms, int fPlayer ) {
 	sin = 0;
 	cos = -1;
     }
-    
+
     Advance( pf, 260 * nMag / 100 );
     ReleaseFont( pf );
     
     if( fPDF ) {
 	/* FIXME most of the following could be encapsulated into a PDF
 	   XObject to optimise the output file */
-	fprintf( pf, "q 1 0 0 1 %d %d cm %.2f 0 0 %.2f 0 0 cm 0.5 g\n",
+	lifprintf( pf, "q 1 0 0 1 %d %d cm %.2f 0 0 %.2f 0 0 cm 0.5 g\n",
 		 225 - 200 * nMag / 100, y, nMag / 100.0, nMag / 100.0 );
 	fputs( "60 10 280 240 re S\n", pf );
 	for( i = 0; i < 6; i++ ) {
@@ -517,12 +635,12 @@ static void PrintPostScriptBoard( FILE *pf, matchstate *pms, int fPlayer ) {
 		 pms->nCube == 1 || pms->nCube > 8 ? -10 : -5,
 		 pms->nCube == 1 ? 64 : pms->nCube );
     } else
-	fprintf( pf, "gsave\n"
-		 "%d %d translate %.2f %.2f scale\n"
-		 "0 0 moveto %s board\n"
-		 "%d %d %d cube\n", 225 - 200 * nMag / 100, y,
-		 nMag / 100.0, nMag / 100.0, fPlayer ? "true" : "false",
-		 pms->nCube == 1 ? 64 : pms->nCube, yCube, theta );
+	lifprintf( pf, "gsave\n"
+		   "%d %d translate %.2f %.2f scale\n"
+		   "0 0 moveto %s board\n"
+		   "%d %d %d cube\n", 225 - 200 * nMag / 100, y,
+		   nMag / 100.0, nMag / 100.0, fPlayer ? "true" : "false",
+		   pms->nCube == 1 ? 64 : pms->nCube, yCube, theta );
 
     for( i = 0; i < 25; i++ ) {
 	anOff[ 0 ] -= pms->anBoard[ 0 ][ i ];
@@ -539,6 +657,12 @@ static void PrintPostScriptBoard( FILE *pf, matchstate *pms, int fPlayer ) {
 	fputs( "Q\n", pf );
     else
 	fputs( "grestore\n", pf );
+
+    /* FIXME: write position ID, match ID, and pip counts */
+
+    PostScriptPositionID ( pf, pms );
+    PostScriptPipCounts ( pf, pms->anBoard, pms->fMove );
+
 }
 
 static short acxTimesRoman[ 256 ] = {
@@ -604,15 +728,21 @@ static int StringWidth( unsigned char *sz ) {
 
 /* Typeset a line of text.  We're not TeX, so we don't do any kerning,
    hyphenation or justification.  Word wrapping will have to do. */
-static void PrintPostScriptComment( FILE *pf, unsigned char *pch ) {
+
+static void PrintPostScriptLineWithSkip( FILE *pf, unsigned char *pch, 
+                                         const int nSkip,
+                                         font fn, int nSize ) {
 
     int x;
-    unsigned char *pchStart, *pchBreak;
+    unsigned char *sz, *pchStart, *pchBreak;
     
     if( !pch || !*pch )
 	return;
 
-    Skip( pf, 6 );
+    pch = sz = Convert( pch, "ISO-8859-1", GNUBG_CHARSET );
+    
+    if ( nSkip )
+      Skip( pf, nSkip );
 
     while( *pch ) {
 	Advance( pf, 10 );
@@ -620,7 +750,7 @@ static void PrintPostScriptComment( FILE *pf, unsigned char *pch ) {
 	pchBreak = NULL;
 	pchStart = pch;
 	
-	for( x = 0; x < 451 * 1000 / 10; x += acxTimesRoman[ *pch++ ] )
+	for( x = 0; x < 451 * 1000 / nSize; x += acxTimesRoman[ *pch++ ] )
 	    if( !*pch ) {
 		/* finished; break here */
 		pchBreak = pch;
@@ -636,7 +766,7 @@ static void PrintPostScriptComment( FILE *pf, unsigned char *pch ) {
 	if( !pchBreak )
 	    pchBreak = ( pch == pchStart ) ? pch : pch - 1;
 
-	RequestFont( pf, FONT_RM, 10 );
+	RequestFont( pf, fn, nSize );
 
 	fprintf( pf, fPDF ? "1 0 0 1 0 %d Tm (" : "0 %d moveto (", y );
 	
@@ -651,7 +781,10 @@ static void PrintPostScriptComment( FILE *pf, unsigned char *pch ) {
 		putc( '\\', pf );
 		/* fall through */
 	    default:
-		putc( *pchStart, pf );
+		if( (unsigned char) *pchStart >= 0x80 )
+		    fprintf( pf, "\\%03o", *pchStart );
+		else
+		    putc( *pchStart, pf );
 	    }
 	fputs( fPDF ? ") Tj\n" : ") show\n", pf );
 
@@ -660,25 +793,57 @@ static void PrintPostScriptComment( FILE *pf, unsigned char *pch ) {
 	
 	pch = pchBreak + 1;
     }
+
+    free( sz );
 }
 
-static void PrintPostScriptCubeAnalysis( FILE *pf, matchstate *pms,
-					 int fPlayer, float arDouble[ 4 ],
-					 evalsetup *pes ) { 
+static void
+PrintPostScriptLine ( FILE *pf, unsigned char *pch ) {
+
+  PrintPostScriptLineWithSkip ( pf, pch, 0, FONT_RM, 10 );
+
+}
+
+static void
+PrintPostScriptLineFont ( FILE *pf, unsigned char *pch, 
+                          font fn, int nSize ) {
+
+  PrintPostScriptLineWithSkip ( pf, pch, 0, fn, nSize );
+
+}
+
+
+
+static void
+PrintPostScriptComment ( FILE *pf, unsigned char *pch ) {
+
+  PrintPostScriptLineWithSkip ( pf, pch, 6, FONT_RM, 10 );
+
+}
+
+
+
+static void 
+PrintPostScriptCubeAnalysis( FILE *pf, const matchstate *pms,
+                             int const fPlayer, 
+                             const float aarOutput[2][ NUM_ROLLOUT_OUTPUTS ], 
+                             const float aarStdDev[2][ NUM_ROLLOUT_OUTPUTS ], 
+                             const evalsetup* pes ) { 
     cubeinfo ci;
-    char sz[ 1024 ], *pch, *pchNext;
+    char *sz, *pch, *pchNext;
 
     if( pes->et == EVAL_NONE )
 	return;
     
     SetCubeInfo( &ci, pms->nCube, pms->fCubeOwner, fPlayer, pms->nMatchTo,
-		 pms->anScore, pms->fCrawford, fJacoby, nBeavers );
+		 pms->anScore, pms->fCrawford, pms->fJacoby, nBeavers,
+                 pms->bgv );
     
     if( !GetDPEq( NULL, NULL, &ci ) )
 	/* No cube action possible */
 	return;
     
-    GetCubeActionSz( arDouble, sz, &ci, fOutputMWC, FALSE );
+    sz = OutputCubeAnalysis( aarOutput, aarStdDev, pes, &ci );
 
     Skip( pf, 4 );
     for( pch = sz; pch && *pch; pch = pchNext ) {
@@ -712,6 +877,128 @@ static void PlayerSymbol( FILE *pf, int x, int fPlayer ) {
 		 fPlayer ? "fill" : "stroke" );
 }
 
+
+static void
+PostScriptMatchInfo ( FILE *pf, matchinfo *pmi ) {
+
+  char sz[ 1000 ];
+  char szx[ 1000 ];
+  int i;
+  struct tm tmx;
+  
+  Ensure ( pf, 100 );
+  Advance ( pf, 14 );
+  PrintPostScriptLineFont ( pf, _("Match Information" ), FONT_RM_BOLD, 14 );
+  Advance ( pf, 6 );
+
+  /* ratings */
+
+  RequestFont ( pf, FONT_RM, 10 );
+  for ( i = 0; i < 2; ++i ) {
+    sprintf ( sz, _("%s's rating: %s"),
+              ap[ i ].szName,
+              pmi->pchRating[ i ] ? pmi->pchRating[ i ] : _("n/a") );
+    PrintPostScriptLine ( pf, sz );
+  }
+
+  /* date */
+
+  if ( pmi->nYear ) {
+
+    tmx.tm_year = pmi->nYear - 1900;
+    tmx.tm_mon = pmi->nMonth - 1;
+    tmx.tm_mday = pmi->nDay;
+    strftime ( szx, sizeof ( szx ), _("%B %d, %Y"), &tmx );
+    sprintf ( sz, _("Date: %s"), szx ); 
+    PrintPostScriptLine ( pf, sz );
+  }
+  else 
+    PrintPostScriptLine ( pf, _("Date: n/a") );
+
+  /* event, round, place and annotator */
+
+  sprintf( sz, _("Event: %s"),
+           pmi->pchEvent ? pmi->pchEvent : _("n/a") );
+  PrintPostScriptLine ( pf, sz );
+
+  sprintf( sz, _("Round: %s"),
+           pmi->pchRound ? pmi->pchRound : _("n/a") );
+  PrintPostScriptLine ( pf, sz );
+
+  sprintf( sz, _("Place: %s"),
+           pmi->pchPlace ? pmi->pchPlace : _("n/a") );
+  PrintPostScriptLine ( pf, sz );
+
+  sprintf( sz, _("Annotator: %s"),
+           pmi->pchAnnotator ? pmi->pchAnnotator : _("n/a") );
+  PrintPostScriptLine ( pf, sz );
+
+  sprintf( sz, _("Comments: %s"),
+           pmi->pchComment ? pmi->pchComment : _("n/a") );
+  PrintPostScriptLine ( pf, sz );
+    
+  ReleaseFont ( pf );
+
+}
+
+static void
+PostScriptBoardHeader ( FILE *pf, matchstate *pms, const int iMove ) {
+
+  /* move number */
+
+  Advance ( pf, 20 );
+  RequestFont ( pf, FONT_RM_BOLD, 10 );
+  fprintf( pf, fPDF ? "1 0 0 1 0 %d Tm (" : "0 %d moveto (", y );
+  fprintf ( pf,_("Move number %d:"), iMove + 1 );
+  fputs( fPDF ? ") Tj\n" : ") show\n", pf );
+
+  RequestFont ( pf, FONT_RM, 10 );
+  fprintf( pf, fPDF ? "1 0 0 1 100 %d Tm (" : "100 %d moveto (", y );
+
+  if ( pms->fResigned ) 
+    
+    /* resignation */
+
+    fprintf ( pf,
+              _("%s resigns %d points"), 
+              ap[ pms->fTurn ].szName,
+              pms->fResigned * pms->nCube
+            );
+  
+  else if ( pms->anDice[ 0 ] && pms->anDice[ 1 ] )
+
+    /* chequer play decision */
+
+    fprintf ( pf,
+              _("%s to play %d%d"),
+              ap[ pms->fTurn ].szName,
+              pms->anDice[ 0 ], pms->anDice[ 1 ] 
+            );
+
+  else if ( pms->fDoubled )
+
+    /* take decision */
+
+    fprintf ( pf,
+              _("%s doubles to %d"),
+              ap[ pms->fMove ].szName,
+              pms->nCube * 2
+            );
+
+  else
+
+    /* cube decision */
+
+    fprintf ( pf,
+              _("%s on roll, cube decision?"),
+              ap[ pms->fTurn ].szName
+            );
+
+  fputs( fPDF ? ") Tj\n" : ") show\n", pf );
+  
+
+}
+
 static void ExportGamePostScript( FILE *pf, list *plGame ) {
 
     list *pl;
@@ -719,40 +1006,89 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
     matchstate msExport;
     int fTook = FALSE, i, cx;
     char sz[ 1024 ], *pch;
+    int iMove = 0;
+
+    updateStatisticsGame ( plGame );
 
     for( pl = plGame->plNext; pl != plGame; pl = pl->plNext ) {
 	pmr = pl->p;
+        FixMatchState ( &msExport, pmr );
 	switch( pmr->mt ) {
 	case MOVE_GAMEINFO:
-	    /* FIXME game introduction */
+
+            ApplyMoveRecord ( &msExport, plGame, pmr );
+          
+	    Ensure( pf, 26 );
+	    Consume( pf, 14 );
+	    RequestFont( pf, FONT_RM, 14 );
+	    if( pmr->g.nMatch )
+		sprintf( sz, _("%d point match (game %d)"), pmr->g.nMatch,
+			 pmr->g.i + 1 );
+	    else
+		sprintf( sz, _("Money session (game %d)"), pmr->g.i + 1 );
+	    
+	    fprintf( pf, fPDF ? "1 0 0 1 0 %d Tm (%s) Tj\n" :
+		     "0 %d moveto (%s) show\n", y, sz );
+
+	    Consume( pf, 12 );
+	    PlayerSymbol( pf, 8, 0 );
+	    RequestFont( pf, FONT_RM, 12 );
+	    fprintf( pf, fPDF ? "1 0 0 1 16 %d Tm (" : "16 %d moveto (",
+		     y );
+	    PostScriptEscape( pf, ap[ 0 ].szName );
+	    fprintf( pf, _(" (%d points)"), pmr->g.anScore[ 0 ] );
+	    fputs( fPDF ? ") Tj\n" : ") show\n", pf );
+	    
+	    PlayerSymbol( pf, 225, 1 );
+	    RequestFont( pf, FONT_RM, 12 );
+	    fprintf( pf, fPDF ? "1 0 0 1 233 %d Tm (" : "233 %d moveto (",
+		     y );
+	    PostScriptEscape( pf, ap[ 1 ].szName );
+	    fprintf( pf, _(" (%d points)"), pmr->g.anScore[ 1 ] );
+	    fputs( fPDF ? ") Tj\n" : ") show\n", pf );
+
+            /* match information */
+
+            if ( exsExport.fIncludeMatchInfo )
+              PostScriptMatchInfo ( pf, &mi );
+	    
 	    break;
 	    
 	case MOVE_NORMAL:
+
+	    msExport.fTurn = msExport.fMove = pmr->n.fPlayer;
+            msExport.anDice[ 0 ] = pmr->n.anRoll[ 0 ];
+            msExport.anDice[ 1 ] = pmr->n.anRoll[ 1 ];
+
 	    if( fTook )
 		/* no need to print board following a double/take */
 		fTook = FALSE;
 	    else {
-		Ensure( pf, 260 * nMag / 100 + 10 );
+		Ensure( pf, 260 * nMag / 100 + 30 );
+		PostScriptBoardHeader ( pf, &msExport, iMove );
 		PrintPostScriptBoard( pf, &msExport, pmr->n.fPlayer );
 	    }
 	    
 	    PrintPostScriptCubeAnalysis( pf, &msExport, pmr->n.fPlayer,
-					 pmr->n.arDouble, &pmr->n.esDouble );
+                                         GCCCONSTAHACK pmr->n.aarOutput,
+					 GCCCONSTAHACK pmr->n.aarStdDev, 
+                                         &pmr->n.esDouble );
 	    
 	    Advance( pf, 10 );
 	    FormatMove( sz, msExport.anBoard, pmr->n.anMove );
 	    RequestFont( pf, FONT_RM, 10 );
 	    cx = 15 /* 2 digits + colon + space */ +
 		StringWidth( aszLuckTypeAbbr[ pmr->n.lt ] ) +
-		StringWidth( aszSkillTypeAbbr[ pmr->n.st ] ) +
+		StringWidth( aszSkillTypeAbbr[ pmr->n.stMove ] ) +
 		StringWidth( sz );
 	    fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (%d%d%s: %s%s) Tj\n" :
 		     "%d %d moveto (%d%d%s: %s%s) show\n",
 		     225 - cx / 2 + 6, y,
 		     pmr->n.anRoll[ 0 ], pmr->n.anRoll[ 1 ],
 		     aszLuckTypeAbbr[ pmr->n.lt ], sz,
-		     aszSkillTypeAbbr[ pmr->n.st ] );
+		     aszSkillTypeAbbr[ pmr->n.stMove ] );
 	    PlayerSymbol( pf, 225 - cx / 2 - 2, pmr->n.fPlayer );
+            /* FIXME: output cube skill as well */
 
 	    if( pmr->n.ml.cMoves ) {
 		Skip( pf, 4 );
@@ -767,9 +1103,9 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 		    fprintf( pf, fPDF ? "1 0 0 1 46 %d Tm (" :
 			     "46 %d moveto (", y );
 		    putc( i == pmr->n.iMove ? '*' : ' ', pf );
-		    FormatMoveHint( sz, msExport.anBoard, &pmr->n.ml, i,
+		    FormatMoveHint( sz, &msExport, &pmr->n.ml, i,
 				    i != pmr->n.iMove ||
-				    i != pmr->n.ml.cMoves - 1 );
+				    i != pmr->n.ml.cMoves - 1, TRUE, TRUE );
 		    pch = strchr( sz, '\n' );
 		    *pch++ = 0;
 		    fputs( sz, pf );
@@ -788,6 +1124,8 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 	    PrintPostScriptComment( pf, pmr->a.sz );
 
 	    Skip( pf, 6 );
+
+            ++iMove;
 	    
 	    break;
 	    
@@ -796,14 +1134,17 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 	    PrintPostScriptBoard( pf, &msExport, pmr->d.fPlayer );
 
 	    PrintPostScriptCubeAnalysis( pf, &msExport, pmr->d.fPlayer,
-					 pmr->d.arDouble, &pmr->d.esDouble );
+                                         GCCCONSTAHACK pmr->d.CubeDecPtr->aarOutput, 
+                                         GCCCONSTAHACK pmr->d.CubeDecPtr->aarStdDev, 
+                                         &pmr->d.CubeDecPtr->esDouble );
 
 	    Advance( pf, 10 );
 	    RequestFont( pf, FONT_RM, 10 );
 	    /* (Double) stringwidth = 29.439 */
 	    cx = StringWidth( aszSkillTypeAbbr[ pmr->d.st ] ) + 29;
-	    fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (Double%s) Tj\n" :
-		     "%d %d moveto (Double%s) show\n", 225 - cx / 2 + 6, y,
+	    fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (%s%s) Tj\n" :
+		     "%d %d moveto (%s%s) show\n", 225 - cx / 2 + 6, y,
+                     _("Double"),
 		     aszSkillTypeAbbr[ pmr->d.st ] );
 	    
 	    PlayerSymbol( pf, 225 - cx / 2 - 2, pmr->n.fPlayer );
@@ -811,6 +1152,8 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 	    PrintPostScriptComment( pf, pmr->a.sz );
 
 	    Skip( pf, 6 );
+
+            ++iMove;
 	    
 	    break;
 	    
@@ -821,8 +1164,9 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 	    RequestFont( pf, FONT_RM, 10 );
 	    /* (Take) stringwidth = 19.9892 */
 	    cx = StringWidth( aszSkillTypeAbbr[ pmr->d.st ] ) + 20;
-	    fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (Take%s) Tj\n" :
-		     "%d %d moveto (Take%s) show\n", 225 - cx / 2 + 6, y,
+	    fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (%s%s) Tj\n" :
+		     "%d %d moveto (%s%s) show\n", 225 - cx / 2 + 6, y,
+                     _("Take"),
 		     aszSkillTypeAbbr[ pmr->d.st ] );
 	    
 	    PlayerSymbol( pf, 225 - cx / 2 - 2, pmr->n.fPlayer );
@@ -830,6 +1174,8 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 	    PrintPostScriptComment( pf, pmr->a.sz );
 
 	    Skip( pf, 6 );
+
+            ++iMove;
 	    
 	    break;
 	    
@@ -838,8 +1184,9 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 	    RequestFont( pf, FONT_RM, 10 );
 	    /* (Drop) stringwidth = 20.5494 */
 	    cx = StringWidth( aszSkillTypeAbbr[ pmr->d.st ] ) + 20;
-	    fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (Drop%s) Tj\n" :
-		     "%d %d moveto (Drop%s) show\n", 225 - cx / 2 + 6, y,
+	    fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (%s%s) Tj\n" :
+		     "%d %d moveto (%s%s) show\n", 225 - cx / 2 + 6, y,
+                     _("Drop"),
 		     aszSkillTypeAbbr[ pmr->d.st ] );
 	    
 	    PlayerSymbol( pf, 225 - cx / 2 - 2, pmr->n.fPlayer );
@@ -848,16 +1195,19 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 
 	    Skip( pf, 6 );
 
+            ++iMove;
+
 	    break;
 	    
 	case MOVE_RESIGN:
 	    Advance( pf, 10 );
 	    RequestFont( pf, FONT_RM, 10 );
 	    /* (Resigns ) stringwidth = 34.1685 */
-	    cx = StringWidth( aszGameResult[ pmr->r.nResigned - 1 ] ) + 34;
-	    fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (Resigns %s) Tj\n" :
-		     "%d %d moveto (Resigns %s) show\n", 225 - cx / 2 + 6, y,
-		     aszGameResult[ pmr->r.nResigned - 1 ] );
+	    cx = StringWidth( gettext ( aszGameResult[ pmr->r.nResigned - 1 ]  ) ) + 34;
+	    fprintf( pf, fPDF ? "1 0 0 1 %d %d Tm (%s %s) Tj\n" :
+		     "%d %d moveto (%s %s) show\n", 225 - cx / 2 + 6, y,
+                     _("Resigns"),
+		     gettext ( aszGameResult[ pmr->r.nResigned - 1 ] ) );
 	    
 	    PlayerSymbol( pf, 225 - cx / 2 - 2, pmr->n.fPlayer );
 	    
@@ -867,12 +1217,18 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 
 	    Skip( pf, 6 );
 
+            ++iMove;
+
 	    break;
 	    	    
 	case MOVE_SETDICE:
 	    /* ignore */
 	    break;
 	    
+	case MOVE_TIME:
+		/* ignore */
+		break;
+
 	case MOVE_SETBOARD:
 	case MOVE_SETCUBEVAL:
 	case MOVE_SETCUBEPOS:
@@ -880,11 +1236,11 @@ static void ExportGamePostScript( FILE *pf, list *plGame ) {
 	    break;
 	}
 
-	ApplyMoveRecord( &msExport, pmr );
+	ApplyMoveRecord( &msExport, plGame, pmr );
     }
     
-    if( ( GameStatus( msExport.anBoard ) ) )
-	/* FIXME print game result */
+    if( ( GameStatus( msExport.anBoard, msExport.bgv ) ) )
+	/* FIXME print game result and statistics */
 	;
     
 }
@@ -894,7 +1250,7 @@ static void PostScriptEpilogue( FILE *pf ) {
     int i;
     long lXRef;
     
-    EndPage( pf );
+    PSEndPage( pf );
 
     if( fPDF ) {
 	StartObject( pf, idPages );
@@ -936,35 +1292,40 @@ static void PostScriptEpilogue( FILE *pf ) {
 static void ExportGameGeneral( int f, char *sz ) {
 
     FILE *pf;
+    char szTitle[ 128 ];
 
     sz = NextToken( &sz );
     
     if( !plGame ) {
-	outputl( "No game in progress (type `new game' to start one)." );
+	outputl( _("No game in progress (type `new game' to start one).") );
 	return;
     }
     
     if( !sz || !*sz ) {
-	outputl( "You must specify a file to export to (see `help export"
-		 "game postscript')." ); /* FIXME not necessarily PS */
+	outputf( _("You must specify a file to export to (see `help export "
+		 "game %s').\n"), f ? "pdf" : "postscript" );
 	return;
     }
 
+    if ( ! confirmOverwrite ( sz, fConfirmSave ) )
+      return;
+
     if( !strcmp( sz, "-" ) ) {
 	if( f ) {
-	    outputl( "PDF files may not be written to standard output ("
-		     "see `help export game pdf')." );
+	    outputl( _("PDF files may not be written to standard output ("
+		     "see `help export game pdf').") );
 	    return;
 	}
 	
 	pf = stdout;
     } else if( !( pf = fopen( sz, f ? "wb" : "w" ) ) ) {
-	perror( sz );
+	outputerr( sz );
 	return;
     }
 
     fPDF = f;
-    PostScriptPrologue( pf );
+    sprintf( szTitle, "%s vs. %s", ap[ 0 ].szName, ap[ 1 ].szName );
+    PostScriptPrologue( pf, FALSE, szTitle );
     
     ExportGamePostScript( pf, plGame );
 
@@ -972,6 +1333,9 @@ static void ExportGameGeneral( int f, char *sz ) {
     
     if( pf != stdout )
 	fclose( pf );
+
+    setDefaultFileName ( sz, f ? PATH_PDF : PATH_POSTSCRIPT );
+
 }
 
 extern void CommandExportGamePDF( char *sz ) {
@@ -988,7 +1352,8 @@ static void ExportMatchGeneral( int f, char *sz ) {
     
     FILE *pf;
     list *pl;
-
+    char szTitle[ 128 ];
+    
     sz = NextToken( &sz );
     
     if( !plGame ) {
@@ -997,26 +1362,30 @@ static void ExportMatchGeneral( int f, char *sz ) {
     }
     
     if( !sz || !*sz ) {
-	outputf( "You must specify a file to export to (see `help export "
-		 "match %s\n').", f ? "pdf" : "postscript" );
+	outputf( _("You must specify a file to export to (see `help export "
+		 "match %s').\n"), f ? "pdf" : "postscript" );
 	return;
     }
 
+    if ( ! confirmOverwrite ( sz, fConfirmSave ) )
+      return;
+
     if( !strcmp( sz, "-" ) ) {
 	if( f ) {
-	    outputl( "PDF files may not be written to standard output ("
-		     "see `help export match pdf')." );
+	    outputl( _("PDF files may not be written to standard output ("
+		     "see `help export match pdf').") );
 	    return;
 	}
 	
 	pf = stdout;
     } else if( !( pf = fopen( sz, f ? "wb" : "w" ) ) ) {
-	perror( sz );
+	outputerr( sz );
 	return;
     }
 
     fPDF = f;
-    PostScriptPrologue( pf );
+    sprintf( szTitle, "%s vs. %s", ap[ 0 ].szName, ap[ 1 ].szName );
+    PostScriptPrologue( pf, FALSE, szTitle );
 
     /* FIXME write match introduction? */
     
@@ -1027,6 +1396,9 @@ static void ExportMatchGeneral( int f, char *sz ) {
     
     if( pf != stdout )
 	fclose( pf );
+
+    setDefaultFileName ( sz, f ? PATH_PDF : PATH_POSTSCRIPT );
+
 }
 
 extern void CommandExportMatchPDF( char *sz ) {
@@ -1038,3 +1410,46 @@ extern void CommandExportMatchPostScript( char *sz ) {
 
     ExportMatchGeneral( FALSE, sz );
 }
+
+extern void CommandExportPositionEPS( char *sz ) {
+
+    FILE *pf;
+    char szTitle[ 32 ];
+	
+    sz = NextToken( &sz );
+    
+    if( ms.gs == GAME_NONE ) {
+	outputl( _("No game in progress (type `new game' to start one).") );
+	return;
+    }
+    
+    if( !sz || !*sz ) {
+	outputl( _("You must specify a file to export to (see `help export "
+		 "position eps').") );
+	return;
+    }
+
+    if ( ! confirmOverwrite ( sz, fConfirmSave ) )
+      return;
+
+    if( !strcmp( sz, "-" ) )
+	pf = stdout;
+    else if( !( pf = fopen( sz, "w" ) ) ) {
+	outputerr( sz );
+	return;
+    }
+
+    fPDF = FALSE;
+    sprintf( szTitle, _("Position %s"), PositionID( ms.anBoard ) );
+    PostScriptPrologue( pf, TRUE, szTitle );
+
+    PrintPostScriptBoard( pf, &ms, ms.fTurn );
+    
+    PostScriptEpilogue( pf );
+
+    if( pf != stdout )
+	fclose( pf );
+
+    setDefaultFileName ( sz, PATH_EPS );
+
+}
