@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: render.c,v 1.29 2004/01/16 09:42:15 uid68519 Exp $
+ * $Id: render.c,v 1.33 2004/03/23 10:15:48 Superfly_Jon Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -274,7 +274,7 @@ static void CopyAreaClip( unsigned char *puchDest, int nDestStride,
     if( cx <= 0 || cy <= 0 )
 	return;
 
-    return CopyArea( puchDest + yDest * nDestStride + xDest * 3, nDestStride,
+    CopyArea( puchDest + yDest * nDestStride + xDest * 3, nDestStride,
 		     puchSrc + ySrc * nSrcStride + xSrc * 3, nSrcStride,
 		     cx, cy );
 }
@@ -288,8 +288,11 @@ extern void CopyAreaRotateClip( unsigned char *puchDest, int nDestStride,
     int x, nSrcPixelStride = 0, nSrcRowStride = 0;
     
     if( !( nTheta %= 4 ) )
-	return CopyAreaClip( puchDest, nDestStride, xDest, yDest, cxDest,
+	{
+		CopyAreaClip( puchDest, nDestStride, xDest, yDest, cxDest,
 			     cyDest, puchSrc, nSrcStride, xSrc, ySrc, cx, cy );
+		return;
+	}
 
     puchSrc += ySrc * nSrcStride + xSrc * 3;
     
@@ -372,7 +375,7 @@ static void FillArea( unsigned char *puchDest, int nDestStride,
     }
 }
 
-extern void AlphaBlend( unsigned char *puchDest, int nDestStride,
+extern void AlphaBlendBase( unsigned char *puchDest, int nDestStride,
 			unsigned char *puchBack, int nBackStride,
 			unsigned char *puchFore, int nForeStride,
 			int cx, int cy ) {
@@ -441,7 +444,7 @@ extern void AlphaBlendClip( unsigned char *puchDest, int nDestStride,
     if( cx <= 0 || cy <= 0 )
 	return;
 
-    AlphaBlend( puchDest + yDest * nDestStride + xDest * 3, nDestStride,
+    AlphaBlendBase( puchDest + yDest * nDestStride + xDest * 3, nDestStride,
 		puchBack + yBack * nBackStride + xBack * 3, nBackStride,
 		puchFore + yFore * nForeStride + xFore * 4, nForeStride,
 		cx, cy );
@@ -654,8 +657,12 @@ static void RenderFramePainted( renderdata *prd, unsigned char *puch,
 				int nStride ) {
     int i, ix;
     float x, z, cos_theta, diffuse, specular;
-    unsigned char colours[ 4 * 3 * prd->nSize ];
-    
+#if __GNUC__ || !HAVE_ALLOCA
+	unsigned char colours[ 4 * 3 * prd->nSize ];
+#else
+	unsigned char *colours = (unsigned char*)alloca( 4 * 3 * prd->nSize * sizeof(unsigned char) );
+#endif
+
     diffuse = 0.8 * prd->arLight[ 2 ] + 0.2;
     specular = pow( prd->arLight[ 2 ], 20 ) * 0.6;
 
@@ -1030,11 +1037,22 @@ static void RenderFrameWood( renderdata *prd, unsigned char *puch,
 
 #define BUF( y, x, i ) ( puch[ (y) * nStride + (x) * 3 + (i) ] )
     
-    int i, x, y, nSpecularTop, anSpecular[ 4 ][ prd->nSize ], nSpecular,
+    int i, x, y, nSpecularTop, nSpecular,
 	s = prd->nSize;
     unsigned char a[ 3 ];
-    float rx, rz, arDiffuse[ 4 ][ s ], cos_theta, rDiffuseTop,
-	arHeight[ s ], rHeight, rDiffuse;
+    float rx, rz, cos_theta, rDiffuseTop, rHeight, rDiffuse;
+#if __GNUC__ || !HAVE_ALLOCA
+	int anSpecular[4][s];
+	float arDiffuse[4][s];
+	float arHeight[s];
+#else
+	int *anSpecularData = alloca( 4 * s * sizeof( int ) );
+	int *anSpecular[4] = { anSpecularData, anSpecularData + s, anSpecularData + 2 * s, anSpecularData + 3 * s };
+	float *arDiffuseData = alloca( 4 * s * sizeof( float ) );
+	float *arDiffuse[4] = { arDiffuseData, arDiffuseData + s, arDiffuseData + 2 * s, arDiffuseData + 3 * s };
+	float *arHeight = alloca( s * sizeof( float ) );
+#endif
+
 
     nSpecularTop = pow( prd->arLight[ 2 ], 20 ) * 0.6 * 0x100;
     rDiffuseTop = 0.8 * prd->arLight[ 2 ] + 0.2;
@@ -1500,10 +1518,16 @@ RenderLabels( renderdata *prd, unsigned char *puch, int nStride,
     FT_Glyph aftg[ 10 ];
 
     if( FT_New_Memory_Face( ftl, auchLuxiSB, cbLuxiSB, 0, &ftf ) )
-	return RenderBasicLabels( prd, puch, nStride, iStart, iEnd, iDelta );
+	{
+		RenderBasicLabels( prd, puch, nStride, iStart, iEnd, iDelta );
+		return;
+	}
     
     if( FT_Set_Pixel_Sizes( ftf, 0, prd->nSize * 5 / 2 ) )
-	return RenderBasicLabels( prd, puch, nStride, iStart, iEnd, iDelta );
+	{
+		RenderBasicLabels( prd, puch, nStride, iStart, iEnd, iDelta );
+		return;
+	}
 
 	if (prd->fLabels)
 	{
@@ -2022,7 +2046,7 @@ extern void RenderCubeFaces( renderdata *prd, unsigned char *puch,
 #endif
     
     for( i = 0; i < 6; i++ ) {
-	AlphaBlend( puch, nStride, puch, nStride, puchCube + prd->nSize * 4 +
+	AlphaBlendBase( puch, nStride, puch, nStride, puchCube + prd->nSize * 4 +
 		    prd->nSize * nStrideCube, nStrideCube,
 		    CUBE_LABEL_WIDTH * prd->nSize, CUBE_LABEL_HEIGHT * prd->nSize );
 
@@ -2039,7 +2063,7 @@ extern void RenderCubeFaces( renderdata *prd, unsigned char *puch,
     }
     
     for( ; i < 12; i++ ) {
-	AlphaBlend( puch, nStride, puch, nStride, puchCube + prd->nSize * 4 +
+	AlphaBlendBase( puch, nStride, puch, nStride, puchCube + prd->nSize * 4 +
  		    prd->nSize * nStrideCube, nStrideCube,
 		    CUBE_LABEL_WIDTH * prd->nSize, CUBE_LABEL_HEIGHT * prd->nSize );
 
@@ -2096,7 +2120,7 @@ extern void RenderResignFaces( renderdata *prd, unsigned char *puch,
 #endif
     
     for( i = 0; i < 3; i++ ) {
-	AlphaBlend( puch, nStride, puch, nStride, puchCube + prd->nSize * 4 +
+	AlphaBlendBase( puch, nStride, puch, nStride, puchCube + prd->nSize * 4 +
 		    prd->nSize * nStrideCube, nStrideCube,
 		    RESIGN_LABEL_WIDTH * prd->nSize, RESIGN_LABEL_HEIGHT * prd->nSize );
 
