@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: show.c,v 1.175 2004/01/16 09:41:39 uid68519 Exp $
+ * $Id: show.c,v 1.180 2004/03/25 20:10:50 thyssen Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,7 @@
 #include <unistd.h>
 #endif
 #include <assert.h>
+#include <ctype.h>
 
 #include "backgammon.h"
 #include "drawboard.h"
@@ -46,6 +47,7 @@
 #include "osr.h"
 #include "positionid.h"
 #include "boarddim.h"
+#include "credits.h"
 
 #if USE_GTK
 #include "gtkboard.h"
@@ -60,6 +62,8 @@
 #include "gtkbearoff.h"
 #elif USE_EXT
 #include "xgame.h"
+#else
+#include <glib.h>
 #endif
 
 extern char *aszCopying[], *aszWarranty[]; /* from copying.c */
@@ -186,8 +190,8 @@ show_evals ( const char *text,
 static void
 show_movefilters ( const movefilter aaamf[ 2 ][ MAX_FILTER_PLIES ][ MAX_FILTER_PLIES ] ) {
 
-  if ( equal_movefilters ( (movefilter (*)[]) aaamf[ 0 ], 
-                           (movefilter (*)[]) aaamf[ 1 ] ) ) 
+  if ( equal_movefilters ( (movefilter (*)[MAX_FILTER_PLIES]) aaamf[ 0 ], 
+                           (movefilter (*)[MAX_FILTER_PLIES]) aaamf[ 1 ] ) ) 
     ShowMoveFilters ( aaamf[ 0 ] );
   else {
     int i;
@@ -440,7 +444,7 @@ extern void CommandShowAnalysis( char *sz ) {
              "following evaluation parameters:") );
   outputl( _("    Chequer play:") );
   ShowEvalSetup ( &esAnalysisChequer );
-  ShowMoveFilters ( (const movefilter (*)[]) aamfAnalysis );
+  ShowMoveFilters ( (const movefilter (*)[MAX_FILTER_PLIES]) aamfAnalysis );
   outputl( _("    Cube decisions:") );
   ShowEvalSetup ( &esAnalysisCube );
 
@@ -728,7 +732,7 @@ extern void CommandShowEvaluation( char *sz ) {
     outputl( _("    Chequer play:") );
     ShowEvalSetup ( &esEvalChequer );
     outputl( _("    Move filters:") );
-    ShowMoveFilters ( (const movefilter (*)[]) aamfEval );
+    ShowMoveFilters ( (const movefilter (*)[MAX_FILTER_PLIES]) aamfEval );
     outputl( _("    Cube decisions:") );
     ShowEvalSetup ( &esEvalCube );
 
@@ -842,7 +846,7 @@ extern void CommandShowPlayer( char *sz ) {
             outputl( _("    Checker play:") );
             ShowEvalSetup ( &ap[ i ].esChequer );
             outputl( _("    Move filters:") );
-            ShowMoveFilters ( (const movefilter (*)[]) ap[ i ].aamf );
+            ShowMoveFilters ( (const movefilter (*)[MAX_FILTER_PLIES]) ap[ i ].aamf );
             outputl( _("    Cube decisions:") );
             ShowEvalSetup ( &ap[ i ].esCube );
 	    break;
@@ -940,6 +944,45 @@ extern void CommandShowTurn( char *sz ) {
 		gettext ( aszGameResult[ ms.fResigned - 1 ] ) );
 }
 
+extern void CommandShowBuildInfo( char *sz )
+{
+#if USE_GTK
+	if( fX )
+		GTKShowBuildInfo();
+#endif
+}
+
+static void
+ShowAuthors( const credEntry ace[], const char *title ) {
+
+  int i;
+
+  outputf( title );
+  outputc( '\n' );
+  
+  for ( i = 0; ace[ i ].Name; ++i ) {
+    if ( !(i % 3) )
+      outputc( '\n' );
+    outputf( "   %-20.20s", ace[ i ].Name );
+  }
+  
+  outputc( '\n' );
+  outputc( '\n' );
+
+}
+
+
+extern void CommandShowCredits( char *sz )
+{
+#if USE_GTK
+  if( fX )
+    GTKCommandShowCredits();
+#endif
+
+  outputl( aszAUTHORS );
+
+}
+
 extern void CommandShowWarranty( char *sz ) {
 
 #if USE_GTK
@@ -1323,26 +1366,8 @@ extern void CommandShowVersion( char *sz ) {
 
     outputc( '\n' );
 
-    /* To avoid gnubg.pot include non US-ASCII char. */
-    outputf( _("GNU Backgammon was written by %s, %s, %s\n%s, %s and %s.\n\n"),
-	       "Joseph Heled", "ystein Johansen", "David Montgomery",
-	       "Jim Segrave", "Jrn Thyssen", "Gary Wong");
-
-    outputl( _("Special thanks to:") );
-
-    cCol = 80;
-
-    for( ppch = aszCredits; *ppch; ppch++ ) {
-	i += ( cch = strlen( *ppch ) + 2 );
-	if( i >= cCol ) {
-	    outputc( '\n' );
-	    i = cch;
-	}
-	
-	outputf( "%s%c ", *ppch, *( ppch + 1 ) ? ',' : '.' );
-    }
-
-    outputc( '\n' );
+    ShowAuthors( ceAuthors, _("GNU Backgammon was written by:") );
+  
 }
 
 extern void CommandShowMarketWindow ( char * sz ) {
@@ -1920,38 +1945,28 @@ outputl(_("Tutor mode evaluates moves using the same settings as Analysis.") );
 
 }
 
-extern void
-CommandShowGeometry ( char *sz ) {
-
-  outputf ( _("Default geometries:\n\n"
-              "Main window       : size %dx%d, position (%d,%d)\n"
-              "Annotation window : size %dx%d, position (%d,%d)\n"
-              "Game list window  : size %dx%d, position (%d,%d)\n"
-              "Hint window       : size %dx%d, position (%d,%d)\n"
-              "Message window    : size %dx%d, position (%d,%d)\n" ),
-            awg[ WINDOW_MAIN ].nWidth,
-            awg[ WINDOW_MAIN ].nHeight,
-            awg[ WINDOW_MAIN ].nPosX,
-            awg[ WINDOW_MAIN ].nPosY,
-            awg[ WINDOW_ANNOTATION ].nWidth,
-            awg[ WINDOW_ANNOTATION ].nHeight,
-            awg[ WINDOW_ANNOTATION ].nPosX,
-            awg[ WINDOW_ANNOTATION ].nPosY,
-            awg[ WINDOW_GAME ].nWidth,
-            awg[ WINDOW_GAME ].nHeight,
-            awg[ WINDOW_GAME ].nPosX,
-            awg[ WINDOW_GAME ].nPosY,
-            awg[ WINDOW_HINT ].nWidth,
-            awg[ WINDOW_HINT ].nHeight,
-            awg[ WINDOW_HINT ].nPosX,
-            awg[ WINDOW_HINT ].nPosY,
-            awg[ WINDOW_MESSAGE ].nWidth,
-            awg[ WINDOW_MESSAGE ].nHeight,
-            awg[ WINDOW_MESSAGE ].nPosX,
-            awg[ WINDOW_MESSAGE ].nPosY );
+static void GetGeometryString(char* buf, windowobject* pwo)
+{
+	char dispName[50];
+	sprintf(dispName, "%c%s %s", toupper(pwo->winName[0]), &pwo->winName[1], _("window"));
 
+	sprintf(buf, "%-17s : size %dx%d, position (%d,%d)\n",
+		dispName, pwo->wg.nWidth, pwo->wg.nHeight, pwo->wg.nPosX, pwo->wg.nPosY);
 }
 
+extern void
+CommandShowGeometry ( char *sz )
+{
+	int i;
+	char szBuf[1024];
+	output(_("Default geometries:\n\n"));
+
+	for (i = 0; i < NUM_WINDOWS; i++)
+	{
+		GetGeometryString(szBuf, &woPanel[i]);
+		output(szBuf);
+	}
+}
 
 extern void CommandShowHighlightColour ( char *sz ) {
 
