@@ -20,13 +20,14 @@
  * File modified by Joern Thyssen <jthyssen@dk.ibm.com> for use with
  * GNU Backgammon.
  *
- * $Id: sound.c,v 1.24 2003/09/12 13:35:24 steink Exp $
+ * $Id: sound.c,v 1.27 2004/03/15 17:45:54 Superfly_Jon Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 #include <assert.h>
+#include <sys/types.h>
 #if HAVE_SYS_AUDIOIO_H
 #include <sys/audioio.h>
 #endif
@@ -43,9 +44,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#if HAVE_SYS_TIME_H
 #include <sys/time.h>
-#include <sys/types.h>
+#endif
+#if HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 
 #if HAVE_ESD
 #include <esd.h>
@@ -61,7 +65,9 @@
 #endif
 
 #ifdef WIN32
-#include "windows.h" /* for PlaySound */
+/* for PlaySound */
+#include "windows.h"
+#include <mmsystem.h>
 #endif
 
 #include "backgammon.h"
@@ -1083,7 +1089,8 @@ play_file_child(soundcache *psc, const char *filename) {
     case SOUND_SYSTEM_WINDOWS:
 
 #ifdef WIN32
-      PlaySound ( filename, NULL, SND_FILENAME | SND_ASYNC );
+      while (!PlaySound(filename, NULL, SND_FILENAME | SND_ASYNC | SND_NOSTOP | SND_NODEFAULT))
+        Sleep(1);	/* Wait (1ms) for previous sound to finish */
 #else
       assert ( FALSE );
 #endif
@@ -1220,6 +1227,14 @@ extern void SoundWait( void ) {
 	
 	return;
     }
+#endif
+#ifdef WIN32
+    case SOUND_SYSTEM_WINDOWS:
+    	/* Wait 1/10 of a second to make sure sound has started */
+    	Sleep(100);
+      while (!PlaySound(NULL, NULL, SND_FILENAME | SND_ASYNC | SND_NOSTOP | SND_NODEFAULT))
+        Sleep(1);	/* Wait (1ms) for previous sound to finish */
+      return;
 #endif
     default:
 	return;
